#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .list_valid_report_names import list_valid_report_names
from .define import define
from .expr_value import expr_value
from .average_over import average_over
from .old_props import old_props
class expression_child(Group):
    """
    'child_object_type' of expression.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['list_valid_report_names', 'define', 'expr_value', 'average_over',
         'old_props']

    list_valid_report_names: list_valid_report_names = list_valid_report_names
    """
    list_valid_report_names child of expression_child.
    """
    define: define = define
    """
    define child of expression_child.
    """
    expr_value: expr_value = expr_value
    """
    expr_value child of expression_child.
    """
    average_over: average_over = average_over
    """
    average_over child of expression_child.
    """
    old_props: old_props = old_props
    """
    old_props child of expression_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_dynamic_strength import enable_dynamic_strength
from .set_dynamic_strength_exponent import set_dynamic_strength_exponent
from .set_maximum_dynamic_strength import set_maximum_dynamic_strength
class anti_diffusion(Group):
    """
    'anti_diffusion' child.
    """

    fluent_name = "anti-diffusion"

    child_names = \
        ['enable_dynamic_strength', 'set_dynamic_strength_exponent',
         'set_maximum_dynamic_strength']

    enable_dynamic_strength: enable_dynamic_strength = enable_dynamic_strength
    """
    enable_dynamic_strength child of anti_diffusion.
    """
    set_dynamic_strength_exponent: set_dynamic_strength_exponent = set_dynamic_strength_exponent
    """
    set_dynamic_strength_exponent child of anti_diffusion.
    """
    set_maximum_dynamic_strength: set_maximum_dynamic_strength = set_maximum_dynamic_strength
    """
    set_maximum_dynamic_strength child of anti_diffusion.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .re_randomize_every_iteration import re_randomize_every_iteration
from .re_randomize_every_timestep import re_randomize_every_timestep
from .tracking_statistics_format import tracking_statistics_format
from .verbosity_1 import verbosity
class expert_options(Group):
    """
    Menu containing not frequently used (expert level) settings.
    """

    fluent_name = "expert-options"

    child_names = \
        ['re_randomize_every_iteration', 're_randomize_every_timestep',
         'tracking_statistics_format', 'verbosity']

    re_randomize_every_iteration: re_randomize_every_iteration = re_randomize_every_iteration
    """
    re_randomize_every_iteration child of expert_options.
    """
    re_randomize_every_timestep: re_randomize_every_timestep = re_randomize_every_timestep
    """
    re_randomize_every_timestep child of expert_options.
    """
    tracking_statistics_format: tracking_statistics_format = tracking_statistics_format
    """
    tracking_statistics_format child of expert_options.
    """
    verbosity: verbosity = verbosity
    """
    verbosity child of expert_options.
    """



"""Module for events management."""
from functools import partial
from typing import Callable, List

from ansys.api.fluent.v0 import events_pb2 as EventsProtoModule
from ansys.fluent.core.streaming_services.streaming import StreamingService


class EventsManager(StreamingService):
    """Manages server-side events.

    This class allows the client to register and unregister callbacks with server events.

    Parameters
    ----------
    session_id : str
        Session ID.
    service :
        Event streaming service.

    Attributes
    ----------
    events_list : List[str]
        List of supported events.
    """

    def __init__(self, session_id: str, service):
        super().__init__(
            target=EventsManager._process_streaming,
            streaming_service=service,
        )
        self._session_id: str = session_id
        self._events_list: List[str] = [
            attr for attr in dir(EventsProtoModule) if attr.endswith("Event")
        ]

    def _process_streaming(self, started_evt):
        responses = self._streaming_service.begin_streaming(started_evt)
        while True:
            try:
                response = next(responses)
                event_name = response.WhichOneof("as")
                with self._lock:
                    self._streaming = True
                    callbacks_map = self._service_callbacks.get(event_name, {})
                    for call_back in callbacks_map.values():
                        call_back(
                            session_id=self._session_id,
                            event_info=getattr(response, event_name),
                        )
            except StopIteration:
                break

    def register_callback(
        self, event_name: str = None, call_back: Callable = None, *args, **kwargs
    ):
        """Register the callback.

        Parameters
        ----------
        event_name : str
            Event name to register the callback to.

        call_back : Callable
            Callback to register.

        Returns
        -------
        str
            Registered callback ID.

        Raises
        ------
        RuntimeError
            If event name is not valid.
        """
        if event_name is None or call_back is None:
            raise RuntimeError(
                "Please provide compulsory arguments : 'event_name' and 'call_back'"
            )

        if event_name not in self.events_list:
            raise RuntimeError(f"{event_name} is not a valid event.")
        with self._lock:
            event_name = event_name.lower()
            callback_id = f"{event_name}-{next(self._service_callback_id)}"
            callbacks_map = self._service_callbacks.get(event_name)
            if callbacks_map:
                callbacks_map.update({callback_id: partial(call_back, *args, **kwargs)})
            else:
                self._service_callbacks[event_name] = {
                    callback_id: partial(call_back, *args, **kwargs)
                }

    def unregister_callback(self, callback_id: str):
        """Unregister the callback.

        Parameters
        ----------
        callback_id : str
            ID of the registered callback.
        """
        with self._lock:
            for callbacks_map in self._service_callbacks.values():
                if callback_id in callbacks_map:
                    del callbacks_map[callback_id]

    @property
    def events_list(self) -> List[str]:
        """Get a list of supported events.

        Parameters
        ----------
        None

        Returns
        -------
        List[str]
            List of supported events.
        """
        return self._events_list



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .min_pressure import min_pressure
from .max_pressure import max_pressure
from .min_temperature import min_temperature
from .max_temperature import max_temperature
from .min_tke import min_tke
from .min_lam_tke import min_lam_tke
from .min_des_tke import min_des_tke
from .min_epsilon import min_epsilon
from .min_des_epsilon import min_des_epsilon
from .min_v2f_tke import min_v2f_tke
from .min_v2f_epsilon import min_v2f_epsilon
from .min_vel_var_scale import min_vel_var_scale
from .min_elliptic_relax_func import min_elliptic_relax_func
from .min_omega import min_omega
from .min_des_omega import min_des_omega
from .max_turb_visc_ratio import max_turb_visc_ratio
from .positivity_rate import positivity_rate
from .min_vol_frac_for_matrix_sol import min_vol_frac_for_matrix_sol
class limits(Group):
    """
    'limits' child.
    """

    fluent_name = "limits"

    child_names = \
        ['min_pressure', 'max_pressure', 'min_temperature', 'max_temperature',
         'min_tke', 'min_lam_tke', 'min_des_tke', 'min_epsilon',
         'min_des_epsilon', 'min_v2f_tke', 'min_v2f_epsilon',
         'min_vel_var_scale', 'min_elliptic_relax_func', 'min_omega',
         'min_des_omega', 'max_turb_visc_ratio', 'positivity_rate',
         'min_vol_frac_for_matrix_sol']

    min_pressure: min_pressure = min_pressure
    """
    min_pressure child of limits.
    """
    max_pressure: max_pressure = max_pressure
    """
    max_pressure child of limits.
    """
    min_temperature: min_temperature = min_temperature
    """
    min_temperature child of limits.
    """
    max_temperature: max_temperature = max_temperature
    """
    max_temperature child of limits.
    """
    min_tke: min_tke = min_tke
    """
    min_tke child of limits.
    """
    min_lam_tke: min_lam_tke = min_lam_tke
    """
    min_lam_tke child of limits.
    """
    min_des_tke: min_des_tke = min_des_tke
    """
    min_des_tke child of limits.
    """
    min_epsilon: min_epsilon = min_epsilon
    """
    min_epsilon child of limits.
    """
    min_des_epsilon: min_des_epsilon = min_des_epsilon
    """
    min_des_epsilon child of limits.
    """
    min_v2f_tke: min_v2f_tke = min_v2f_tke
    """
    min_v2f_tke child of limits.
    """
    min_v2f_epsilon: min_v2f_epsilon = min_v2f_epsilon
    """
    min_v2f_epsilon child of limits.
    """
    min_vel_var_scale: min_vel_var_scale = min_vel_var_scale
    """
    min_vel_var_scale child of limits.
    """
    min_elliptic_relax_func: min_elliptic_relax_func = min_elliptic_relax_func
    """
    min_elliptic_relax_func child of limits.
    """
    min_omega: min_omega = min_omega
    """
    min_omega child of limits.
    """
    min_des_omega: min_des_omega = min_des_omega
    """
    min_des_omega child of limits.
    """
    max_turb_visc_ratio: max_turb_visc_ratio = max_turb_visc_ratio
    """
    max_turb_visc_ratio child of limits.
    """
    positivity_rate: positivity_rate = positivity_rate
    """
    positivity_rate child of limits.
    """
    min_vol_frac_for_matrix_sol: min_vol_frac_for_matrix_sol = min_vol_frac_for_matrix_sol
    """
    min_vol_frac_for_matrix_sol child of limits.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class courant_number_reduction(Real):
    """
    Coarse-grid Courant number reduction factor.
    """

    fluent_name = "courant-number-reduction"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .create_zones_from_ccl import create_zones_from_ccl
from .read import read
from .chemkin_report_each_line import chemkin_report_each_line
from .import_fmu import import_fmu
class import_(Group):
    """
    'import' child.
    """

    fluent_name = "import"

    child_names = \
        ['create_zones_from_ccl']

    create_zones_from_ccl: create_zones_from_ccl = create_zones_from_ccl
    """
    create_zones_from_ccl child of import_.
    """
    command_names = \
        ['read', 'chemkin_report_each_line', 'import_fmu']

    read: read = read
    """
    read command of import_.
    """
    chemkin_report_each_line: chemkin_report_each_line = chemkin_report_each_line
    """
    chemkin_report_each_line command of import_.
    """
    import_fmu: import_fmu = import_fmu
    """
    import_fmu command of import_.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .species_diffusivity_child import species_diffusivity_child

class species_diffusivity(NamedObject[species_diffusivity_child], _NonCreatableNamedObjectMixin[species_diffusivity_child]):
    """
    'species_diffusivity' child.
    """

    fluent_name = "species-diffusivity"

    child_object_type: species_diffusivity_child = species_diffusivity_child
    """
    child_object_type of species_diffusivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .beach_dir_list_child import beach_dir_list_child

class beach_dir_list(ListObject[beach_dir_list_child]):
    """
    'beach_dir_list' child.
    """

    fluent_name = "beach-dir-list"

    child_object_type: beach_dir_list_child = beach_dir_list_child
    """
    child_object_type of beach_dir_list.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class enable_high_res_tracking(Boolean):
    """
    Enable/disable high resolution tracking. Please note that high-resolution tracking is the recommended default for highest tracking robustness, accuracy and performance.
    """

    fluent_name = "enable-high-res-tracking?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .custom_vector import custom_vector
from .field import field
from .surfaces import surfaces
from .geometry_1 import geometry
from .physics import physics
from .retain_instantaneous_values import retain_instantaneous_values
from .report_type import report_type
from .phase_25 import phase
from .average_over import average_over
from .per_surface import per_surface
from .old_props import old_props
from .surface_names import surface_names
from .surface_ids import surface_ids
class surface_child(Group):
    """
    'child_object_type' of surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['custom_vector', 'field', 'surfaces', 'geometry', 'physics',
         'retain_instantaneous_values', 'report_type', 'phase',
         'average_over', 'per_surface', 'old_props', 'surface_names',
         'surface_ids']

    custom_vector: custom_vector = custom_vector
    """
    custom_vector child of surface_child.
    """
    field: field = field
    """
    field child of surface_child.
    """
    surfaces: surfaces = surfaces
    """
    surfaces child of surface_child.
    """
    geometry: geometry = geometry
    """
    geometry child of surface_child.
    """
    physics: physics = physics
    """
    physics child of surface_child.
    """
    retain_instantaneous_values: retain_instantaneous_values = retain_instantaneous_values
    """
    retain_instantaneous_values child of surface_child.
    """
    report_type: report_type = report_type
    """
    report_type child of surface_child.
    """
    phase: phase = phase
    """
    phase child of surface_child.
    """
    average_over: average_over = average_over
    """
    average_over child of surface_child.
    """
    per_surface: per_surface = per_surface
    """
    per_surface child of surface_child.
    """
    old_props: old_props = old_props
    """
    old_props child of surface_child.
    """
    surface_names: surface_names = surface_names
    """
    surface_names child of surface_child.
    """
    surface_ids: surface_ids = surface_ids
    """
    surface_ids child of surface_child.
    """



from ansys.fluent.core.services.datamodel_se import PyCallableStateObject


def _new_command_for_task(task, session):
    class NewCommandError(Exception):
        def __init__(self, task_name):
            super().__init__(f"Could not create command for meshing task {task_name}")

    task_cmd_name = task.CommandName()
    cmd_creator = getattr(session, task_cmd_name)
    if cmd_creator:
        new_cmd = cmd_creator.create_instance()
        if new_cmd:
            return new_cmd
    raise NewCommandError(task._name_())


class WorkflowWrapper:
    class TaskContainer(PyCallableStateObject):
        def __init__(self, command_source):
            self._container = command_source
            self._task_container = command_source._workflow.TaskObject

        def __getitem__(self, name):
            return WorkflowWrapper.Task(self._container, name)

        def __getattr__(self, attr):
            return getattr(self._task_container, attr)

        def __dir__(self):
            return sorted(
                set(
                    list(self.__dict__.keys())
                    + dir(type(self))
                    + dir(self._task_container)
                )
            )

    class Task(PyCallableStateObject):
        def __init__(self, command_source, name):
            self.__dict__.update(
                dict(
                    _workflow=command_source._workflow,
                    _source=command_source._command_source,
                    _task=command_source._workflow.TaskObject[name],
                    _cmd=None,
                )
            )

        @property
        def CommandArguments(self):
            return self._refreshed_command()

        def _refreshed_command(self):
            task_arg_state = self.Arguments.get_state()
            cmd = self._command()
            if task_arg_state:
                cmd.set_state(task_arg_state)
            return _MakeReadOnly(self._cmd_sub_items_read_only(cmd))

        def _cmd_sub_items_read_only(self, cmd):
            for item in cmd():
                if type(getattr(cmd, item).get_state()) == dict:
                    setattr(
                        cmd, item, self._cmd_sub_items_read_only(getattr(cmd, item))
                    )
                setattr(cmd, item, _MakeReadOnly(getattr(cmd, item)))
            return cmd

        def _command(self):
            if not self._cmd:
                self._cmd = _new_command_for_task(self._task, self._source)
            return self._cmd

        def __getattr__(self, attr):
            return getattr(self._task, attr)

        def __setattr__(self, attr, value):
            if attr in self.__dict__:
                self.__dict__[attr] = value
            else:
                setattr(self._task, attr, value)

        def __dir__(self):
            return sorted(
                set(list(self.__dict__.keys()) + dir(type(self)) + dir(self._task))
            )

    def __init__(self, workflow, command_source):
        self._workflow = workflow
        self._command_source = command_source

    def task(self, name):
        return WorkflowWrapper.Task(self, name)

    @property
    def TaskObject(self):
        return WorkflowWrapper.TaskContainer(self)

    def __getattr__(self, attr):
        return getattr(self._workflow, attr)

    def __dir__(self):
        return sorted(
            set(list(self.__dict__.keys()) + dir(type(self)) + dir(self._workflow))
        )

    def __call__(self):
        return self._workflow()


class _MakeReadOnly:
    """Removes 'set_state()' attribute to implement read-only behaviour."""

    _unwanted_attr = ["set_state", "setState"]

    def __init__(self, cmd):
        self._cmd = cmd

    def __getattr__(self, attr):
        if attr in _MakeReadOnly._unwanted_attr:
            raise AttributeError("Command Arguments are read-only.")
        return getattr(self._cmd, attr)

    def __dir__(self):
        returned_list = sorted(
            set(list(self.__dict__.keys()) + dir(type(self)) + dir(self._cmd))
        )
        for attr in _MakeReadOnly._unwanted_attr:
            if attr in returned_list:
                returned_list.remove(attr)
        return returned_list

    def __call__(self):
        return self._cmd()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .x_format import x_format
from .x_axis_precision import x_axis_precision
from .y_format import y_format
from .y_axis_precision import y_axis_precision
class numbers(Group):
    """
    'numbers' child.
    """

    fluent_name = "numbers"

    child_names = \
        ['x_format', 'x_axis_precision', 'y_format', 'y_axis_precision']

    x_format: x_format = x_format
    """
    x_format child of numbers.
    """
    x_axis_precision: x_axis_precision = x_axis_precision
    """
    x_axis_precision child of numbers.
    """
    y_format: y_format = y_format
    """
    y_format child of numbers.
    """
    y_axis_precision: y_axis_precision = y_axis_precision
    """
    y_axis_precision child of numbers.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .equations_child import equations_child

class equations(NamedObject[equations_child], _CreatableNamedObjectMixin[equations_child]):
    """
    'equations' child.
    """

    fluent_name = "equations"

    child_object_type: equations_child = equations_child
    """
    child_object_type of equations.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class maximum_cell_count(Integer):
    """
    Set limit on the maximum number of cells during adaption.
    """

    fluent_name = "maximum-cell-count"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .random_eddy_lifetime import random_eddy_lifetime
from .number_of_tries import number_of_tries
from .time_scale_constant import time_scale_constant
class turbulent_dispersion(Group):
    """
    'turbulent_dispersion' child.
    """

    fluent_name = "turbulent-dispersion"

    child_names = \
        ['option', 'random_eddy_lifetime', 'number_of_tries',
         'time_scale_constant']

    option: option = option
    """
    option child of turbulent_dispersion.
    """
    random_eddy_lifetime: random_eddy_lifetime = random_eddy_lifetime
    """
    random_eddy_lifetime child of turbulent_dispersion.
    """
    number_of_tries: number_of_tries = number_of_tries
    """
    number_of_tries child of turbulent_dispersion.
    """
    time_scale_constant: time_scale_constant = time_scale_constant
    """
    time_scale_constant child of turbulent_dispersion.
    """



"""Metaclasses used in various explicit classes in PyFluent."""
from abc import ABCMeta
from collections.abc import MutableMapping
from pprint import pformat

# pylint: disable=unused-private-member
# pylint: disable=bad-mcs-classmethod-argument


class Attribute:
    VALID_NAMES = ["range", "allowed_values"]

    def __init__(self, function):
        self.function = function

    def __set_name__(self, obj, name):
        if name not in self.VALID_NAMES:
            raise ValueError(
                f"Attribute {name} is not allowed."
                f"Expected values are {self.VALID_NAMES}"
            )
        if not hasattr(obj, "attributes"):
            obj.attributes = set()
        obj.attributes.add(name)

    def __set__(self, obj, value):
        raise AttributeError("Attributes are read only.")

    def __get__(self, obj, objtype=None):
        return self.function(obj)


class PyLocalBaseMeta(type):
    @classmethod
    def __create_get_parent_by_type(cls):
        def wrapper(self, obj_type, obj=None):
            obj = self if obj is None else obj
            parent = None
            if getattr(obj, "_parent", None):
                if isinstance(obj._parent, obj_type):
                    return obj._parent
                parent = self._get_parent_by_type(obj_type, obj._parent)
            return parent

        return wrapper

    @classmethod
    def __create_get_top_most_parent(cls):
        def wrapper(self, obj=None):
            obj = self if obj is None else obj
            parent = obj
            if getattr(obj, "_parent", None):
                parent = self._get_top_most_parent(obj._parent)
            return parent

        return wrapper

    def __new__(cls, name, bases, attrs):
        attrs["_get_parent_by_type"] = cls.__create_get_parent_by_type()
        attrs["_get_top_most_parent"] = cls.__create_get_top_most_parent()
        return super(PyLocalBaseMeta, cls).__new__(cls, name, bases, attrs)


class PyLocalPropertyMeta(PyLocalBaseMeta):
    """Metaclass for local property classes."""

    @classmethod
    def __create_validate(cls):
        def wrapper(self, value):
            attrs = getattr(self, "attributes", None)
            if attrs:
                for attr in attrs:
                    if attr == "range":
                        if self.range and (
                            value < self.range[0] or value > self.range[1]
                        ):
                            raise ValueError(
                                f"Value {value}, is not within valid range"
                                f" {self.range}."
                            )
                    elif attr == "allowed_values":
                        if isinstance(value, list):
                            if not all(
                                v is None or v in self.allowed_values for v in value
                            ):
                                raise ValueError(
                                    f"Not all values in {value}, are in the "
                                    "list of allowed values "
                                    f"{self.allowed_values}."
                                )
                        elif value is not None and value not in self.allowed_values:
                            raise ValueError(
                                f"Value {value}, is not in the list of "
                                f"allowed values {self.allowed_values}."
                            )

            return value

        return wrapper

    @classmethod
    def __create_init(cls):
        def wrapper(self, parent, api_helper):
            self._api_helper = api_helper(self)
            self._parent = parent
            self._on_change_cbs = []
            annotations = self.__class__.__dict__.get("__annotations__")
            if isinstance(getattr(self.__class__, "value", None), property):
                value_annotation = annotations.get("_value")
            else:
                value_annotation = annotations.get("value")
            self._type = value_annotation
            reset_on_change = (
                hasattr(self, "_reset_on_change")
                and getattr(self, "_reset_on_change")()
            )
            if reset_on_change:
                for obj in reset_on_change:
                    obj._register_on_change_cb(lambda: setattr(self, "_value", None))

        return wrapper

    @classmethod
    def __create_get_state(cls, show_attributes=False):
        def wrapper(self):
            try:
                return self.value
            except AttributeError:
                return None

        return wrapper

    @classmethod
    def __create_set_state(cls):
        def wrapper(self, value, validate=True):
            self.value = self._validate(value) if validate else value
            for on_change_cb in self._on_change_cbs:
                on_change_cb()

        return wrapper

    @classmethod
    def __create_register_on_change(cls):
        def wrapper(self, on_change_cb):
            self._on_change_cbs.append(on_change_cb)

        return wrapper

    @classmethod
    def __create_repr(cls):
        def wrapper(self):
            data = self()
            return f"{data}"

        return wrapper

    def __new__(cls, name, bases, attrs):
        attrs["__init__"] = cls.__create_init()
        attrs["__call__"] = cls.__create_get_state()
        attrs["__repr__"] = cls.__create_repr()
        attrs["_validate"] = cls.__create_validate()
        attrs["_register_on_change_cb"] = cls.__create_register_on_change()
        attrs["set_state"] = cls.__create_set_state()
        return super(PyLocalPropertyMeta, cls).__new__(cls, name, bases, attrs)


class PyLocalObjectMeta(PyLocalBaseMeta):
    """Metaclass for local object classes."""

    @classmethod
    def __create_init(cls):
        def wrapper(self, parent, api_helper):
            self._parent = parent
            self._api_helper = api_helper(self)

            def update(clss):
                for name, cls in clss.__dict__.items():
                    if cls.__class__.__name__ in (
                        "PyLocalPropertyMeta",
                        "PyLocalObjectMeta",
                    ):
                        setattr(
                            self,
                            name,
                            cls(self, api_helper),
                        )
                    if cls.__class__.__name__ == "PyLocalNamedObjectMeta":
                        setattr(
                            self,
                            cls.PLURAL,
                            PyLocalContainer(self, cls, api_helper),
                        )
                for base_class in clss.__bases__:
                    update(base_class)

            update(self.__class__)

        return wrapper

    @classmethod
    def __create_getattribute(cls):
        def wrapper(self, name):
            if name == "_availability":
                return object.__getattribute__(self, "_availability")
            availability = (
                getattr(self, "_availability")(name)
                if hasattr(self, "_availability")
                else True
            )
            if availability:
                return object.__getattribute__(self, name)
            else:
                return None

        return wrapper

    @classmethod
    def __create_updateitem(cls):
        def wrapper(self, value):
            for name, val in value.items():
                obj = getattr(self, name)
                if obj.__class__.__class__.__name__ == "PyLocalPropertyMeta":
                    obj.set_state(val)
                else:
                    obj.update(val)

        wrapper.__doc__ = "Update object."
        return wrapper

    @classmethod
    def __create_get_state(cls):
        def wrapper(self, show_attributes=False):
            state = {}

            def update_state(clss):
                for name, cls in clss.__dict__.items():

                    availability = (
                        getattr(self, "_availability")(name)
                        if hasattr(self, "_availability")
                        else True
                    )
                    if availability:
                        o = getattr(self, name)
                        if cls.__class__.__name__ == "PyLocalObjectMeta":
                            state[name] = o(show_attributes)

                        if cls.__class__.__name__ == "PyLocalPropertyMeta":
                            state[name] = o()
                            attrs = show_attributes and getattr(o, "attributes", None)
                            if attrs:
                                for attr in attrs:
                                    state[name + "." + attr] = getattr(o, attr)

                for base_class in clss.__bases__:
                    update_state(base_class)

            update_state(self.__class__)
            return state

        return wrapper

    @classmethod
    def __create_setattr(cls):
        def wrapper(self, name, value):
            attr = getattr(self, name, None)
            if attr and attr.__class__.__class__.__name__ == "PyLocalPropertyMeta":
                attr.set_state(value)
            else:
                object.__setattr__(self, name, value)

        return wrapper

    @classmethod
    def __create_repr(cls):
        def wrapper(self):
            return pformat(self(True), depth=1, indent=2)

        return wrapper

    def __new__(cls, name, bases, attrs):
        attrs["__getattribute__"] = cls.__create_getattribute()
        attrs["__init__"] = attrs.get("__init__", cls.__create_init())
        attrs["__call__"] = cls.__create_get_state()
        attrs["__setattr__"] = cls.__create_setattr()
        attrs["__repr__"] = cls.__create_repr()
        attrs["update"] = cls.__create_updateitem()
        return super(PyLocalObjectMeta, cls).__new__(cls, name, bases, attrs)


class PyLocalNamedObjectMeta(PyLocalObjectMeta):
    """Metaclass for local named object classes."""

    @classmethod
    def __create_init(cls):
        def wrapper(self, name, parent, api_helper):
            self._name = name
            self._api_helper = api_helper(self)
            self._parent = parent

            def update(clss):
                for name, cls in clss.__dict__.items():
                    if cls.__class__.__name__ in (
                        "PyLocalPropertyMeta",
                        "PyLocalObjectMeta",
                    ):
                        setattr(
                            self,
                            name,
                            cls(self, api_helper),
                        )
                    if cls.__class__.__name__ == "PyLocalNamedObjectMeta":
                        setattr(
                            self,
                            cls.PLURAL,
                            PyLocalContainer(self, cls, api_helper),
                        )
                for base_class in clss.__bases__:
                    update(base_class)

            update(self.__class__)

        return wrapper

    def __new__(cls, name, bases, attrs):
        attrs["__init__"] = cls.__create_init()
        return super(PyLocalNamedObjectMeta, cls).__new__(cls, name, bases, attrs)


class PyLocalNamedObjectMetaAbstract(ABCMeta, PyLocalNamedObjectMeta):
    pass


class PyLocalContainer(MutableMapping):
    """Local container for named objects."""

    def __init__(self, parent, object_class, api_helper):
        self._parent = parent
        self.__object_class = object_class
        self.__collection: dict = {}
        self.__api_helper = api_helper

    def __iter__(self):
        return iter(self.__collection)

    def __len__(self):
        return len(self.__collection)

    def __getitem__(self, name):
        o = self.__collection.get(name, None)
        if not o:
            o = self.__collection[name] = self.__object_class(
                name, self, self.__api_helper
            )
        return o

    def __setitem__(self, name, value):
        o = self[name]
        o.update(value)

    def __delitem__(self, name):
        del self.__collection[name]



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class use_automatic_intersection_tolerance(Boolean):
    """
    Enable/disable using an automatic scaling of subtet intersection tolerance.
    """

    fluent_name = "use-automatic-intersection-tolerance?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .orthotropic_structure_nu import orthotropic_structure_nu
class struct_poisson_ratio(Group):
    """
    'struct_poisson_ratio' child.
    """

    fluent_name = "struct-poisson-ratio"

    child_names = \
        ['option', 'value', 'orthotropic_structure_nu']

    option: option = option
    """
    option child of struct_poisson_ratio.
    """
    value: value = value
    """
    value child of struct_poisson_ratio.
    """
    orthotropic_structure_nu: orthotropic_structure_nu = orthotropic_structure_nu
    """
    orthotropic_structure_nu child of struct_poisson_ratio.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .histogram import histogram
from .sample_trajectories import sample_trajectories
from .summary import summary
from .extended_summary import extended_summary
from .zone_summaries_per_injection import zone_summaries_per_injection
class discrete_phase(Group):
    """
    'discrete_phase' child.
    """

    fluent_name = "discrete-phase"

    child_names = \
        ['histogram', 'sample_trajectories']

    histogram: histogram = histogram
    """
    histogram child of discrete_phase.
    """
    sample_trajectories: sample_trajectories = sample_trajectories
    """
    sample_trajectories child of discrete_phase.
    """
    command_names = \
        ['summary', 'extended_summary', 'zone_summaries_per_injection']

    summary: summary = summary
    """
    summary command of discrete_phase.
    """
    extended_summary: extended_summary = extended_summary
    """
    extended_summary command of discrete_phase.
    """
    zone_summaries_per_injection: zone_summaries_per_injection = zone_summaries_per_injection
    """
    zone_summaries_per_injection command of discrete_phase.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .adapt import adapt
from .check_before_solve import check_before_solve
from .check_verbosity import check_verbosity
from .enhanced_orthogonal_quality import enhanced_orthogonal_quality
from .matching_tolerance import matching_tolerance
from .show_periodic_shadow_zones import show_periodic_shadow_zones
from .reorder import reorder
from .repair_improve import repair_improve
from .surface_mesh import surface_mesh
from .polyhedra import polyhedra
from .adjacency import adjacency
from .check import check
from .memory_usage import memory_usage
from .mesh_info import mesh_info
from .quality import quality
from .rotate import rotate
from .scale import scale
from .size_info import size_info
from .redistribute_boundary_layer import redistribute_boundary_layer
from .swap_mesh_faces import swap_mesh_faces
from .smooth_mesh import smooth_mesh
from .replace import replace
from .translate import translate
class mesh(Group):
    """
    'mesh' child.
    """

    fluent_name = "mesh"

    child_names = \
        ['adapt', 'check_before_solve', 'check_verbosity',
         'enhanced_orthogonal_quality', 'matching_tolerance',
         'show_periodic_shadow_zones', 'reorder', 'repair_improve',
         'surface_mesh', 'polyhedra']

    adapt: adapt = adapt
    """
    adapt child of mesh.
    """
    check_before_solve: check_before_solve = check_before_solve
    """
    check_before_solve child of mesh.
    """
    check_verbosity: check_verbosity = check_verbosity
    """
    check_verbosity child of mesh.
    """
    enhanced_orthogonal_quality: enhanced_orthogonal_quality = enhanced_orthogonal_quality
    """
    enhanced_orthogonal_quality child of mesh.
    """
    matching_tolerance: matching_tolerance = matching_tolerance
    """
    matching_tolerance child of mesh.
    """
    show_periodic_shadow_zones: show_periodic_shadow_zones = show_periodic_shadow_zones
    """
    show_periodic_shadow_zones child of mesh.
    """
    reorder: reorder = reorder
    """
    reorder child of mesh.
    """
    repair_improve: repair_improve = repair_improve
    """
    repair_improve child of mesh.
    """
    surface_mesh: surface_mesh = surface_mesh
    """
    surface_mesh child of mesh.
    """
    polyhedra: polyhedra = polyhedra
    """
    polyhedra child of mesh.
    """
    command_names = \
        ['adjacency', 'check', 'memory_usage', 'mesh_info', 'quality',
         'rotate', 'scale', 'size_info', 'redistribute_boundary_layer',
         'swap_mesh_faces', 'smooth_mesh', 'replace', 'translate']

    adjacency: adjacency = adjacency
    """
    adjacency command of mesh.
    """
    check: check = check
    """
    check command of mesh.
    """
    memory_usage: memory_usage = memory_usage
    """
    memory_usage command of mesh.
    """
    mesh_info: mesh_info = mesh_info
    """
    mesh_info command of mesh.
    """
    quality: quality = quality
    """
    quality command of mesh.
    """
    rotate: rotate = rotate
    """
    rotate command of mesh.
    """
    scale: scale = scale
    """
    scale command of mesh.
    """
    size_info: size_info = size_info
    """
    size_info command of mesh.
    """
    redistribute_boundary_layer: redistribute_boundary_layer = redistribute_boundary_layer
    """
    redistribute_boundary_layer command of mesh.
    """
    swap_mesh_faces: swap_mesh_faces = swap_mesh_faces
    """
    swap_mesh_faces command of mesh.
    """
    smooth_mesh: smooth_mesh = smooth_mesh
    """
    smooth_mesh command of mesh.
    """
    replace: replace = replace
    """
    replace command of mesh.
    """
    translate: translate = translate
    """
    translate command of mesh.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option import option
from .update_sources_every_flow_iteration import update_sources_every_flow_iteration
from .iteration_interval import iteration_interval
class interaction(Group):
    """
    'interaction' child.
    """

    fluent_name = "interaction"

    child_names = \
        ['option', 'update_sources_every_flow_iteration',
         'iteration_interval']

    option: option = option
    """
    option child of interaction.
    """
    update_sources_every_flow_iteration: update_sources_every_flow_iteration = update_sources_every_flow_iteration
    """
    update_sources_every_flow_iteration child of interaction.
    """
    iteration_interval: iteration_interval = iteration_interval
    """
    iteration_interval child of interaction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class rel_perm_satw_p2(String):
    """
    'rel_perm_satw_p2' child.
    """

    fluent_name = "rel-perm-satw-p2"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class reset_pseudo_time_method_relaxations(Command):
    """
    'reset_pseudo_time_method_relaxations' command.
    """

    fluent_name = "reset-pseudo-time-method-relaxations"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .solution_stabilization import solution_stabilization
from .verbosity_1 import verbosity
from .parameters import parameters
from .spatial import spatial
from .transient import transient
from .amg import amg
from .models_2 import models
from .methods import methods
from .miscellaneous import miscellaneous
from .set_settings_to_default import set_settings_to_default
class contact_solution_controls(Group):
    """
    'contact_solution_controls' child.
    """

    fluent_name = "contact-solution-controls"

    child_names = \
        ['solution_stabilization', 'verbosity', 'parameters', 'spatial',
         'transient', 'amg', 'models', 'methods', 'miscellaneous']

    solution_stabilization: solution_stabilization = solution_stabilization
    """
    solution_stabilization child of contact_solution_controls.
    """
    verbosity: verbosity = verbosity
    """
    verbosity child of contact_solution_controls.
    """
    parameters: parameters = parameters
    """
    parameters child of contact_solution_controls.
    """
    spatial: spatial = spatial
    """
    spatial child of contact_solution_controls.
    """
    transient: transient = transient
    """
    transient child of contact_solution_controls.
    """
    amg: amg = amg
    """
    amg child of contact_solution_controls.
    """
    models: models = models
    """
    models child of contact_solution_controls.
    """
    methods: methods = methods
    """
    methods child of contact_solution_controls.
    """
    miscellaneous: miscellaneous = miscellaneous
    """
    miscellaneous child of contact_solution_controls.
    """
    command_names = \
        ['set_settings_to_default']

    set_settings_to_default: set_settings_to_default = set_settings_to_default
    """
    set_settings_to_default command of contact_solution_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .simulation_reports import simulation_reports
from .discrete_phase_1 import discrete_phase
from .fluxes import fluxes
from .flow import flow
from .modified_setting_options import modified_setting_options
from .population_balance import population_balance
from .heat_exchange import heat_exchange
from .system import system
from .print_write_histogram import print_write_histogram
from .aero_optical_distortions import aero_optical_distortions
from .forces import forces
from .mphase_summary import mphase_summary
from .particle_summary import particle_summary
from .path_line_summary import path_line_summary
from .projected_surface_area import projected_surface_area
from .summary_1 import summary
from .surface_integrals import surface_integrals
from .volume_integrals import volume_integrals
class report(Group):
    """
    'report' child.
    """

    fluent_name = "report"

    child_names = \
        ['simulation_reports', 'discrete_phase', 'fluxes', 'flow',
         'modified_setting_options', 'population_balance', 'heat_exchange',
         'system', 'print_write_histogram']

    simulation_reports: simulation_reports = simulation_reports
    """
    simulation_reports child of report.
    """
    discrete_phase: discrete_phase = discrete_phase
    """
    discrete_phase child of report.
    """
    fluxes: fluxes = fluxes
    """
    fluxes child of report.
    """
    flow: flow = flow
    """
    flow child of report.
    """
    modified_setting_options: modified_setting_options = modified_setting_options
    """
    modified_setting_options child of report.
    """
    population_balance: population_balance = population_balance
    """
    population_balance child of report.
    """
    heat_exchange: heat_exchange = heat_exchange
    """
    heat_exchange child of report.
    """
    system: system = system
    """
    system child of report.
    """
    print_write_histogram: print_write_histogram = print_write_histogram
    """
    print_write_histogram child of report.
    """
    command_names = \
        ['aero_optical_distortions', 'forces', 'mphase_summary',
         'particle_summary', 'path_line_summary', 'projected_surface_area',
         'summary', 'surface_integrals', 'volume_integrals']

    aero_optical_distortions: aero_optical_distortions = aero_optical_distortions
    """
    aero_optical_distortions command of report.
    """
    forces: forces = forces
    """
    forces command of report.
    """
    mphase_summary: mphase_summary = mphase_summary
    """
    mphase_summary command of report.
    """
    particle_summary: particle_summary = particle_summary
    """
    particle_summary command of report.
    """
    path_line_summary: path_line_summary = path_line_summary
    """
    path_line_summary command of report.
    """
    projected_surface_area: projected_surface_area = projected_surface_area
    """
    projected_surface_area command of report.
    """
    summary: summary = summary
    """
    summary command of report.
    """
    surface_integrals: surface_integrals = surface_integrals
    """
    surface_integrals command of report.
    """
    volume_integrals: volume_integrals = volume_integrals
    """
    volume_integrals command of report.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_19 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment
from .kc import kc
from .hc import hc
from .t_1 import t
from .q_1 import q
from .dpm_bc_type import dpm_bc_type
from .dpm_bc_collision_partner import dpm_bc_collision_partner
from .reinj_inj import reinj_inj
from .dpm_bc_udf import dpm_bc_udf
from .strength import strength
class radiator_child(Group):
    """
    'child_object_type' of radiator.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'kc', 'hc', 't', 'q',
         'dpm_bc_type', 'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'strength']

    phase: phase = phase
    """
    phase child of radiator_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of radiator_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of radiator_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of radiator_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of radiator_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of radiator_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of radiator_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of radiator_child.
    """
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment = porous_jump_turb_wall_treatment
    """
    porous_jump_turb_wall_treatment child of radiator_child.
    """
    kc: kc = kc
    """
    kc child of radiator_child.
    """
    hc: hc = hc
    """
    hc child of radiator_child.
    """
    t: t = t
    """
    t child of radiator_child.
    """
    q: q = q
    """
    q child of radiator_child.
    """
    dpm_bc_type: dpm_bc_type = dpm_bc_type
    """
    dpm_bc_type child of radiator_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner = dpm_bc_collision_partner
    """
    dpm_bc_collision_partner child of radiator_child.
    """
    reinj_inj: reinj_inj = reinj_inj
    """
    reinj_inj child of radiator_child.
    """
    dpm_bc_udf: dpm_bc_udf = dpm_bc_udf
    """
    dpm_bc_udf child of radiator_child.
    """
    strength: strength = strength
    """
    strength child of radiator_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_4 import option
from .expert_options import expert_options
from .hybrid_options import hybrid_options
class parallel(Group):
    """
    Main menu to allow users to set options controlling the parallel scheme used when tracking particles. 
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "parallel"

    child_names = \
        ['option', 'expert_options', 'hybrid_options']

    option: option = option
    """
    option child of parallel.
    """
    expert_options: expert_options = expert_options
    """
    expert_options child of parallel.
    """
    hybrid_options: hybrid_options = hybrid_options
    """
    hybrid_options child of parallel.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enhanced_numerics import enhanced_numerics
from .alternate_bc_formulation import alternate_bc_formulation
from .analytical_thermodynamic_derivatives import analytical_thermodynamic_derivatives
class compressible_flow(Group):
    """
    Multiphase compressible numerics options menu.
    """

    fluent_name = "compressible-flow"

    child_names = \
        ['enhanced_numerics', 'alternate_bc_formulation',
         'analytical_thermodynamic_derivatives']

    enhanced_numerics: enhanced_numerics = enhanced_numerics
    """
    enhanced_numerics child of compressible_flow.
    """
    alternate_bc_formulation: alternate_bc_formulation = alternate_bc_formulation
    """
    alternate_bc_formulation child of compressible_flow.
    """
    analytical_thermodynamic_derivatives: analytical_thermodynamic_derivatives = analytical_thermodynamic_derivatives
    """
    analytical_thermodynamic_derivatives child of compressible_flow.
    """



"""Wrappers over StateEngine based datamodel gRPC service of Fluent."""
from enum import Enum
import itertools
from typing import Any, Dict, Iterator, List, Tuple
import warnings

import grpc

from ansys.api.fluent.v0 import datamodel_se_pb2 as DataModelProtoModule
from ansys.api.fluent.v0 import datamodel_se_pb2_grpc as DataModelGrpcModule
from ansys.api.fluent.v0.variant_pb2 import Variant
from ansys.fluent.core.services.error_handler import catch_grpc_error
from ansys.fluent.core.services.interceptors import TracingInterceptor

Path = List[Tuple[str, str]]


class Attribute(Enum):
    """Contains the standard names of data model attributes associated with the
    data model service."""

    IS_ACTIVE = "isActive"
    EXPOSURE_LEVEL = "exposureLevel"
    IS_READ_ONLY = "isReadOnly"
    DEFAULT = "default"
    FORCE_DEFAULT = "forceDefault"
    MIN = "min"
    MAX = "max"
    ALLOWED_VALUES = "allowedValues"
    EXCLUDED_VALUES = "excludedValues"
    MIN_LENGTH = "minLength"
    MAX_LENGTH = "maxLength"
    ERROR_STATUS = "errorStatus"
    USER_ERROR_STATUS = "userErrorStatus"
    MEMBERS = "members"
    DISPLAY_TEXT = "displayText"
    NAMES = "__names__"
    INTERNAL_NAMES = "__ids__"
    PATHS = "__paths__"
    ROOT_ID = "__root__"
    NAME = "_name_"
    REFERENCE_PATH = "referencePath"
    ARGUMENTS = "arguments"
    TOOL_TIP = "toolTip"
    SHOW_AT_PARENT_NODE = "showAtParentNode"
    WIDGET_TYPE = "widgetType"
    ECHO_MODE = "echoMode"
    IS_TREE_NODE = "isTreeNode"
    MIGRATION = "migration"
    DEPRECATED_VERSION = "deprecatedVersion"


class DatamodelService:
    """Wraps the StateEngine-based datamodel gRPC service of Fluent.

    Using the methods from the ``PyMenu`` class is recommended.
    """

    def __init__(self, channel: grpc.Channel, metadata: List[Tuple[str, str]]):
        tracing_interceptor = TracingInterceptor()
        intercept_channel = grpc.intercept_channel(channel, tracing_interceptor)
        self.__stub = DataModelGrpcModule.DataModelStub(intercept_channel)
        self.__metadata = metadata

    @catch_grpc_error
    def initialize_datamodel(
        self, request: DataModelProtoModule.InitDatamodelRequest
    ) -> DataModelProtoModule.InitDatamodelResponse:
        return self.__stub.initDatamodel(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_attribute_value(
        self, request: DataModelProtoModule.GetAttributeValueRequest
    ) -> DataModelProtoModule.GetAttributeValueResponse:
        return self.__stub.getAttributeValue(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_state(
        self, request: DataModelProtoModule.GetStateRequest
    ) -> DataModelProtoModule.GetStateResponse:
        return self.__stub.getState(request, metadata=self.__metadata)

    @catch_grpc_error
    def set_state(
        self, request: DataModelProtoModule.SetStateRequest
    ) -> DataModelProtoModule.SetStateResponse:
        return self.__stub.setState(request, metadata=self.__metadata)

    @catch_grpc_error
    def update_dict(
        self, request: DataModelProtoModule.UpdateDictRequest
    ) -> DataModelProtoModule.UpdateDictResponse:
        return self.__stub.updateDict(request, metadata=self.__metadata)

    @catch_grpc_error
    def delete_object(
        self, request: DataModelProtoModule.DeleteObjectRequest
    ) -> DataModelProtoModule.DeleteObjectResponse:
        return self.__stub.deleteObject(request, metadata=self.__metadata)

    @catch_grpc_error
    def execute_command(
        self, request: DataModelProtoModule.ExecuteCommandRequest
    ) -> DataModelProtoModule.ExecuteCommandResponse:
        return self.__stub.executeCommand(request, metadata=self.__metadata)

    @catch_grpc_error
    def create_command_arguments(
        self, request: DataModelProtoModule.CreateCommandArgumentsRequest
    ) -> DataModelProtoModule.CreateCommandArgumentsResponse:
        return self.__stub.createCommandArguments(request, metadata=self.__metadata)

    @catch_grpc_error
    def delete_command_arguments(
        self, request: DataModelProtoModule.DeleteCommandArgumentsRequest
    ) -> DataModelProtoModule.DeleteCommandArgumentsResponse:
        return self.__stub.deleteCommandArguments(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_specs(
        self, request: DataModelProtoModule.GetSpecsRequest
    ) -> DataModelProtoModule.GetSpecsResponse:
        return self.__stub.getSpecs(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_static_info(
        self, request: DataModelProtoModule.GetStaticInfoRequest
    ) -> DataModelProtoModule.GetStaticInfoResponse:
        return self.__stub.getStaticInfo(request, metadata=self.__metadata)


def _convert_value_to_variant(val: Any, var: Variant):
    """Convert a Python data type to Fluent's variant type."""

    if isinstance(val, bool):
        var.bool_state = val
    elif isinstance(val, int):
        var.int64_state = val
    elif isinstance(val, float):
        var.double_state = val
    elif isinstance(val, str):
        var.string_state = val
    elif isinstance(val, (list, tuple)):
        # set the one_of to variant_vector_state
        var.variant_vector_state.item.add()
        var.variant_vector_state.item.pop()
        for item in val:
            item_var = var.variant_vector_state.item.add()
            _convert_value_to_variant(item, item_var)
    elif isinstance(val, dict):
        for k, v in val.items():
            _convert_value_to_variant(v, var.variant_map_state.item[k])


def _convert_variant_to_value(var: Variant):
    """Convert Fluent's variant type to a Python data type."""

    if var.HasField("bool_state"):
        return var.bool_state
    elif var.HasField("int64_state"):
        return var.int64_state
    elif var.HasField("double_state"):
        return var.double_state
    elif var.HasField("string_state"):
        return var.string_state
    elif var.HasField("bool_vector_state"):
        return var.bool_vector_state.item
    elif var.HasField("int64_vector_state"):
        return var.int64_vector_state.item
    elif var.HasField("double_vector_state"):
        return var.double_vector_state.item
    elif var.HasField("string_vector_state"):
        return var.string_vector_state.item
    elif var.HasField("variant_vector_state"):
        val = []
        for item in var.variant_vector_state.item:
            val.append(_convert_variant_to_value(item))
        return val
    elif var.HasField("variant_map_state"):
        val = {}
        for k, v in var.variant_map_state.item.items():
            val[k] = _convert_variant_to_value(v)
        return val


def _convert_path_to_se_path(path: Path) -> str:
    """Convert a path structure to a StateEngine path.

    Parameters
    ----------
    path : Path
        Path structure.

    Returns
    -------
    str
        stateengine path
    """
    se_path = ""
    for comp in path:
        se_path += "/" + comp[0]
        if comp[1]:
            se_path += ":" + comp[1]
    return se_path


class PyCallableStateObject:
    """Any object which can be called to get its state.

    Methods
    -------
    __call__()
        Get the state of the current object.
    """

    def __call__(self, *args, **kwds) -> Any:
        return self.get_state()


class PyStateContainer(PyCallableStateObject):
    """Object class using StateEngine based DatamodelService as backend. Use
    this class instead of directly calling DatamodelService's method.

    Methods
    -------
    get_attrib_value(attrib)
        Get the attribute value of the current object.
    getAttribValue(attrib)
        Get the attribute value of the current object.
        (This method is the same as the get_attrib_value(attrib)
        method.)
    get_state()
        Get the state of the current object.
    getState()
        Deprecated camel case alias of get_state.
    set_state()
        Set the state of the current object.
    setState()
        Deprecated camel case alias of set_state.
    __call__()
        Set the state of the current object if state is provided else get its state.
    """

    def __init__(self, service: DatamodelService, rules: str, path: Path = None):
        super().__init__()
        self.service = service
        self.rules = rules
        if path is None:
            self.path = []
        else:
            self.path = path

    docstring = None

    def get_state(self) -> Any:
        request = DataModelProtoModule.GetStateRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        response = self.service.get_state(request)
        return _convert_variant_to_value(response.state)

    getState = get_state

    def set_state(self, state: Any = None, **kwargs) -> None:
        request = DataModelProtoModule.SetStateRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        _convert_value_to_variant(
            kwargs, request.state
        ) if kwargs else _convert_value_to_variant(state, request.state)
        self.service.set_state(request)

    setState = set_state

    def get_attrib_value(self, attrib: str) -> Any:
        """Get attribute value of the current object.

        Parameters
        ----------
        attrib : str
            Name of the attribute.

        Returns
        -------
        Any
            Value of the attribute.
        """
        request = DataModelProtoModule.GetAttributeValueRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        request.attribute = attrib
        response = self.service.get_attribute_value(request)
        return _convert_variant_to_value(response.result)

    getAttribValue = get_attrib_value

    def is_active(self):
        """Returns true if the parameter is active."""
        return true_if_none(self.get_attrib_value(Attribute.IS_ACTIVE.value))

    def help(self) -> None:
        """Print help string."""
        request = DataModelProtoModule.GetSpecsRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        response = self.service.get_specs(request)
        help_string = getattr(
            response.member, response.member.WhichOneof("as")
        ).common.helpstring
        print(help_string)

    def __call__(self, *args, **kwargs):
        if kwargs:
            self.set_state(kwargs)
        elif args:
            self.set_state(args)
        else:
            return self.get_state()

    docstring = None


class PyMenu(PyStateContainer):
    """Object class using StateEngine based DatamodelService as backend. Use
    this class instead of directly calling DatamodelService's method.

    Methods
    -------
    __setattr__(name, value)
        Set state of the child object
    create_command_arguments(command)
    """

    def __init__(self, service: DatamodelService, rules: str, path: Path = None):
        super().__init__(service, rules, path)

    def __setattr__(self, name: str, value: Any):
        """Set state of the child object.

        Parameters
        ----------
        name : str
            child object name
        value : Any
            state
        """
        if hasattr(self, name) and isinstance(getattr(self, name), PyStateContainer):
            getattr(self, name).set_state(value)
        else:
            super().__setattr__(name, value)

    def rename(self, new_name: str) -> None:
        """Rename the named object.

        Parameters
        ----------
        new_name : str
            New name for the object.
        """
        try:
            self._name_.set_state(new_name)
        except AttributeError:
            raise RuntimeError(
                f"{self.__class__.__name__} is not a named object class."
            )

    def raise_method_not_yet_implemented_exception(self):
        raise AttributeError("This method is yet to be implemented in pyfluent.")

    def delete_child(self):
        self.raise_method_not_yet_implemented_exception()

    def delete_child_objects(self):
        self.raise_method_not_yet_implemented_exception()

    def delete_all_child_objects(self):
        self.raise_method_not_yet_implemented_exception()

    def fix_state(self):
        self.raise_method_not_yet_implemented_exception()

    def create_command_arguments(self, command):
        request = DataModelProtoModule.CreateCommandArgumentsRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        request.command = command
        response = self.service.create_command_arguments(request)
        return response.commandid


class PyParameter(PyStateContainer):
    """Object class using StateEngine based DatamodelService as backend.

    Use this class instead of directly calling DatamodelService's
    method.
    """

    def default_value(self):
        """Get default value of the parameter."""
        return self.get_attrib_value(Attribute.DEFAULT.value)

    def is_read_only(self):
        return true_if_none(self.get_attrib_value(Attribute.IS_READ_ONLY.value))


def true_if_none(val):
    """Returns true if 'val' is true or None, else returns false."""
    if val in [True, False, None]:
        return True if val is None else val
    else:
        raise RuntimeError(f"In-correct value passed")


class PyTextual(PyParameter):
    """Provides interface for textual parameters."""

    def allowed_values(self):
        return self.get_attrib_value(Attribute.ALLOWED_VALUES.value)


class PyNumerical(PyParameter):
    """Provides interface for numerical parameters."""

    def min(self):
        return self.get_attrib_value(Attribute.MIN.value)

    def max(self):
        return self.get_attrib_value(Attribute.MAX.value)


class PyDictionary(PyParameter):
    """Provides interface for dictionaries.
    Methods
        -------
        update_dict(dict_state)
            Update the state of the current object if the current object
            is a Dict in the data model, else throws RuntimeError
            (currently not showing up in Python). Update is executed according
            to dict.update semantics
        updateDict(dict_state)
            Update the state of the current object if the current object
            is a Dict in the data model, else throws RuntimeError
            (currently not showing up in Python). Update is executed according
            to dict.update semantics (same as update_dict(dict_state))
    """

    def update_dict(self, dict_state: Dict[str, Any]) -> None:
        request = DataModelProtoModule.UpdateDictRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        _convert_value_to_variant(dict_state, request.dicttomerge)
        self.service.update_dict(request)

    updateDict = update_dict


class PyNamedObjectContainer:
    """Container class using the StateEngine-based DatamodelService as the
    backend. Use this class instead of directly calling the DatamodelService's
    method.

    Methods
    -------
    __len__()
        Return a count of the child objects.
    __iter__()
        Return the next child object.
    __getitem__(key)
        Return the child object by key.
    __setitem__(key, value)
        Set the state of the child object by name.
    __delitem__(key)
        Delete the child object by name.
    """

    def __init__(self, service: DatamodelService, rules: str, path: Path = None):
        self.service = service
        self.rules = rules
        if path is None:
            self.path = []
        else:
            self.path = path

    def _get_child_object_names(self):
        request = DataModelProtoModule.GetSpecsRequest()
        request.rules = self.rules
        parent_path = self.path[0:-1]
        child_type_suffix = self.path[-1][0] + ":"
        request.path = _convert_path_to_se_path(parent_path)
        response = self.service.get_specs(request)
        child_object_names = []
        for struct_type in ("singleton", "namedobject"):
            if response.member.HasField(struct_type):
                struct_field = getattr(response.member, struct_type)
                for member in struct_field.members:
                    if member.startswith(child_type_suffix):
                        child_object_names.append(member[len(child_type_suffix) :])
        return child_object_names

    def _get_child_object_display_names(self):
        child_object_display_names = []
        for name in self._get_child_object_names():
            name_path = self.path[0:-1]
            name_path.append((self.path[-1][0], name))
            name_path.append(("_name_", ""))
            child_object_display_names.append(
                PyMenu(self.service, self.rules, name_path).get_state()
            )
        return child_object_display_names

    def __len__(self) -> int:
        """Return a count of child objects.

        Returns
        -------
        int
            Count of child objects.
        """
        return len(self._get_child_object_display_names())

    def __iter__(self) -> Iterator[PyMenu]:
        """Return the next child object.

        Yields
        -------
        Iterator[PyMenu]
            Iterator of child objects.
        """
        for name in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], name))
            yield getattr(self.__class__, f"_{self.__class__.__name__}")(
                self.service, self.rules, child_path
            )

    def _get_item(self, key: str):
        if key in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], key))
            return getattr(self.__class__, f"_{self.__class__.__name__}")(
                self.service, self.rules, child_path
            )
        else:
            raise LookupError(
                f"{key} is not found at path " f"{_convert_path_to_se_path(self.path)}"
            )

    def _del_item(self, key: str):
        if key in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], key))
            request = DataModelProtoModule.DeleteObjectRequest()
            request.rules = self.rules
            request.path = _convert_path_to_se_path(child_path)
            self.service.delete_object(request)
        else:
            raise LookupError(
                f"{key} is not found at path " f"{_convert_path_to_se_path(self.path)}"
            )

    def __getitem__(self, key: str) -> PyMenu:
        """Return the child object by key.

        Parameters
        ----------
        key : str
            Name of the child object.

        Returns
        -------
        PyMenu
            Child object.
        """
        return self._get_item(key)

    def __setitem__(self, key: str, value: Any):
        """Set state of the child object by name.

        Parameters
        ----------
        key : str
            Name of the child object.
        value : Any
            State of the child object.
        """
        if isinstance(value, dict) and not value:
            value["_name_"] = key
        parent_state = {f"{self.__class__.__name__}:{key}": value}
        PyMenu(self.service, self.rules, self.path[:-1]).set_state(parent_state)

    def __delitem__(self, key: str):
        """Delete the child object by name.

        Parameters
        ----------
        key : str
            Name of the child object.
        """
        self._del_item(key)


class PyCommand:
    """Command class using the StateEngine-based DatamodelService as the
    backend. Use this class instead of directly calling the DatamodelService's
    method.

    Methods
    -------
    __call__()
        Execute the command.
    help()
        Print the command help string.
    """

    docstring = None
    _stored_static_info = {}

    def __init__(
        self, service: DatamodelService, rules: str, command: str, path: Path = None
    ):
        self.service = service
        self.rules = rules
        self.command = command
        if path is None:
            self.path = []
        else:
            self.path = path

    def __call__(self, *args, **kwds) -> Any:
        """Execute the command.

        Returns
        -------
        Any
            Return value.
        """
        request = DataModelProtoModule.ExecuteCommandRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        request.command = self.command
        request.wait = True
        _convert_value_to_variant(kwds, request.args)
        response = self.service.execute_command(request)
        return _convert_variant_to_value(response.result)

    def help(self) -> None:
        """Prints help string."""
        request = DataModelProtoModule.GetSpecsRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        response = self.service.get_specs(request)
        help_string = getattr(
            response.member, response.member.WhichOneof("as")
        ).common.helpstring
        print(help_string)

    def _create_command_arguments(self):
        request = DataModelProtoModule.CreateCommandArgumentsRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        request.command = self.command
        response = self.service.create_command_arguments(request)
        return response.commandid

    def _get_static_info(self):
        if self.rules not in PyCommand._stored_static_info.keys():
            # Populate the static info with respect to a rules only if the
            # same info has not been obtained in another context already.
            # If the information is available, we can use it without additional remote calls.
            request = DataModelProtoModule.GetStaticInfoRequest()
            request.rules = self.rules
            response = self.service.get_static_info(request)
            PyCommand._stored_static_info[self.rules] = response.info
        return PyCommand._stored_static_info[self.rules]

    def create_instance(self):
        try:
            static_info = self._get_static_info()
            id = self._create_command_arguments()
            return PyCommandArguments(
                self.service,
                self.rules,
                self.command,
                self.path.copy(),
                id,
                static_info,
            )
        except RuntimeError:
            warnings.warn(
                "Create command arguments object is available from 23.1 onwards"
            )
            pass


class PyCommandArgumentsSubItem(PyCallableStateObject):
    def __init__(
        self,
        parent,
        name: str,
        service: DatamodelService,
        rules: str,
        path: Path,
        parent_arg,
    ):
        self.parent = parent
        self.name = name

        self.service = service
        self.rules = rules
        self.path = path
        self.parent_arg = parent_arg

    def get_state(self) -> Any:
        parent_state = self.parent.get_state()
        try:
            return parent_state[self.name]
        except KeyError:
            pass

    getState = get_state

    def get_attrib_value(self, attrib: str) -> Any:
        attrib_path = f"{self.name}/{attrib}"
        return self.parent.get_attrib_value(attrib_path)

    getAttribValue = get_attrib_value

    def help(self) -> None:
        pass


class PyCommandArguments(PyStateContainer):
    def __init__(
        self,
        service: DatamodelService,
        rules: str,
        command: str,
        path: Path,
        id: str,
        static_info,
    ):
        self.static_info = static_info
        super().__init__(service, rules, path)
        self.path.append((command, id))
        self.command = command
        self.id = id

    def __del__(self):
        request = DataModelProtoModule.DeleteCommandArgumentsRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path[:-1])
        request.command = self.path[-1][0]
        request.commandid = self.path[-1][1]
        try:
            self.service.delete_command_arguments(request)
        except ValueError:
            # "Cannot invoke RPC on closed channel!"
            pass

    def __getattr__(self, attr):

        for arg in self.static_info.commands[self.command].commandinfo.args:
            if arg.name == attr:
                mode = AccessorModes.get_mode(arg.type)
                py_class = mode.value[1]
                return py_class(self, attr, self.service, self.rules, self.path, arg)


class PyTextualCommandArgumentsSubItem(PyCommandArgumentsSubItem, PyTextual):
    def __init__(
        self,
        parent,
        attr,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ):
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )
        PyTextual.__init__(self, service, rules, path)


class PyNumericalCommandArgumentsSubItem(PyCommandArgumentsSubItem, PyNumerical):
    def __init__(
        self,
        parent,
        attr,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ):
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )
        PyNumerical.__init__(self, service, rules, path)


class PyDictionaryCommandArgumentsSubItem(PyCommandArgumentsSubItem, PyDictionary):
    def __init__(
        self,
        parent,
        attr,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ):
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )
        PyDictionary.__init__(self, service, rules, path)


class PyParameterCommandArgumentsSubItem(PyCommandArgumentsSubItem, PyParameter):
    def __init__(
        self,
        parent,
        attr,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ):
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )
        PyParameter.__init__(self, service, rules, path)


class PySingletonCommandArgumentsSubItem(PyCommandArgumentsSubItem):
    def __init__(
        self,
        parent,
        attr,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ):
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )

    def __getattr__(self, attr):
        arg = self.parent_arg.info.parameters[attr]

        mode = AccessorModes.get_mode(arg.type)
        py_class = mode.value[1]
        return py_class(self, attr, self.service, self.rules, self.path, arg)


class AccessorModes(Enum):
    """Provides the standard Fluent launch modes."""

    # Tuple:   Name, Solver object type, Meshing flag, Launcher options
    TEXT = (["String", "ListString", "String List"], PyTextualCommandArgumentsSubItem)
    NUMBER = (
        ["Real", "Int", "ListReal", "Real List", "Integer"],
        PyNumericalCommandArgumentsSubItem,
    )
    DICTIONARY = (["Dict"], PyDictionaryCommandArgumentsSubItem)
    PARAMETER = (
        ["Bool", "Logical", "Logical List"],
        PyParameterCommandArgumentsSubItem,
    )
    MODELOBJECT = (["ModelObject"], PySingletonCommandArgumentsSubItem)

    @staticmethod
    def get_mode(mode: str) -> "AccessorModes":
        """Returns the LaunchMode based on the mode in string format."""
        for m in AccessorModes:
            if mode in m.value[0]:
                return m
        else:
            raise TypeError(f"The specified mode: {mode} was not found.")


class PyMenuGeneric(PyMenu):
    attrs = ("service", "rules", "path")

    def _get_child_names(self):
        request = DataModelProtoModule.GetSpecsRequest()
        request.rules = self.rules
        request.path = _convert_path_to_se_path(self.path)
        response = self.service.get_specs(request)
        singleton_names = []
        creatable_type_names = []
        command_names = []
        for struct_type in ("singleton", "namedobject"):
            if response.member.HasField(struct_type):
                struct_field = getattr(response.member, struct_type)
                for member in struct_field.members:
                    if ":" not in member:
                        singleton_names.append(member)
                creatable_type_names = struct_field.creatabletypes
                command_names = [x.name for x in struct_field.commands]
        return singleton_names, creatable_type_names, command_names

    def _get_child(self, name: str):
        singletons, creatable_types, commands = self._get_child_names()
        if name in singletons:
            child_path = self.path + [(name, "")]
            return PyMenuGeneric(self.service, self.rules, child_path)
        elif name in creatable_types:
            child_path = self.path + [(name, "")]
            return PyNamedObjectContainerGeneric(self.service, self.rules, child_path)
        elif name in commands:
            return PyCommand(self.service, self.rules, name, self.path)
        else:
            raise LookupError(
                f"{name} is not found at path " f"{_convert_path_to_se_path(self.path)}"
            )

    def __dir__(self):
        return list(itertools.chain(*self._get_child_names()))

    def __getattr__(self, name: str):
        if name in PyMenuGeneric.attrs:
            return super().__getattr__(name)
        else:
            return self._get_child(name)


class PySimpleMenuGeneric(PyMenu, PyDictionary):
    """A simple implementation of PyMenuGeneric applicable only for SINGLETONS.

    This is required for the stand-alone datamodel server to avoid the
    usage of 'service.get_specs'
    """

    attrs = ("service", "rules", "path")

    def _get_child(self, name: str):
        child_path = self.path + [(name, "")]
        return PySimpleMenuGeneric(self.service, self.rules, child_path)

    def __getattr__(self, name: str):
        if name in PySimpleMenuGeneric.attrs:
            return super().__getattr__(name)
        else:
            return self._get_child(name)


class PyNamedObjectContainerGeneric(PyNamedObjectContainer):
    def __iter__(self):
        for name in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], name))
            yield PyMenuGeneric(self.service, self.rules, child_path)

    def _get_item(self, key: str):
        if key in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], key))
            return PyMenuGeneric(self.service, self.rules, child_path)
        else:
            raise LookupError(
                f"{key} is not found at path " f"{_convert_path_to_se_path(self.path)}"
            )



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class cff_files(Boolean):
    """
    Indicate whether to write ANSYS common fluids format (CFF) files or legacy case and data files.
    """

    fluent_name = "cff-files?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .orthotropic_structure_te import orthotropic_structure_te
class struct_thermal_expansion(Group):
    """
    'struct_thermal_expansion' child.
    """

    fluent_name = "struct-thermal-expansion"

    child_names = \
        ['option', 'value', 'orthotropic_structure_te']

    option: option = option
    """
    option child of struct_thermal_expansion.
    """
    value: value = value
    """
    value child of struct_thermal_expansion.
    """
    orthotropic_structure_te: orthotropic_structure_te = orthotropic_structure_te
    """
    orthotropic_structure_te child of struct_thermal_expansion.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .command_list import command_list
from .filename import filename
class export_modifications(Command):
    """
    Export all case modifications to a tsv file.
    
    Parameters
    ----------
        command_list : typing.List[str]
            'command_list' child.
        filename : str
            'filename' child.
    
    """

    fluent_name = "export-modifications"

    argument_names = \
        ['command_list', 'filename']

    command_list: command_list = command_list
    """
    command_list argument of export_modifications.
    """
    filename: filename = filename
    """
    filename argument of export_modifications.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class average_every_step(Boolean):
    """
    Do the averaging after each integration step for higher accuracy at a higher cost.
    """

    fluent_name = "average-every-step?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class limit_pressure_correction_gradient(Boolean):
    """
    Use limited pressure correction gradient in skewness corrections for better stability.
    """

    fluent_name = "limit-pressure-correction-gradient?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .density_1 import density
from .specific_heat_1 import specific_heat
from .thermal_conductivity_1 import thermal_conductivity
from .atomic_number import atomic_number
from .absorption_coefficient import absorption_coefficient
from .scattering_coefficient_1 import scattering_coefficient
from .scattering_phase_function import scattering_phase_function
from .refractive_index import refractive_index
from .uds_diffusivity_1 import uds_diffusivity
from .electric_conductivity import electric_conductivity
from .dual_electric_conductivity import dual_electric_conductivity
from .lithium_diffusivity import lithium_diffusivity
from .magnetic_permeability import magnetic_permeability
from .struct_youngs_modulus import struct_youngs_modulus
from .struct_poisson_ratio import struct_poisson_ratio
from .struct_start_temperature import struct_start_temperature
from .struct_thermal_expansion import struct_thermal_expansion
from .struct_damping_alpha import struct_damping_alpha
from .struct_damping_beta import struct_damping_beta
class solid_child(Group):
    """
    'child_object_type' of solid.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'specific_heat', 'thermal_conductivity', 'atomic_number',
         'absorption_coefficient', 'scattering_coefficient',
         'scattering_phase_function', 'refractive_index', 'uds_diffusivity',
         'electric_conductivity', 'dual_electric_conductivity',
         'lithium_diffusivity', 'magnetic_permeability',
         'struct_youngs_modulus', 'struct_poisson_ratio',
         'struct_start_temperature', 'struct_thermal_expansion',
         'struct_damping_alpha', 'struct_damping_beta']

    density: density = density
    """
    density child of solid_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of solid_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of solid_child.
    """
    atomic_number: atomic_number = atomic_number
    """
    atomic_number child of solid_child.
    """
    absorption_coefficient: absorption_coefficient = absorption_coefficient
    """
    absorption_coefficient child of solid_child.
    """
    scattering_coefficient: scattering_coefficient = scattering_coefficient
    """
    scattering_coefficient child of solid_child.
    """
    scattering_phase_function: scattering_phase_function = scattering_phase_function
    """
    scattering_phase_function child of solid_child.
    """
    refractive_index: refractive_index = refractive_index
    """
    refractive_index child of solid_child.
    """
    uds_diffusivity: uds_diffusivity = uds_diffusivity
    """
    uds_diffusivity child of solid_child.
    """
    electric_conductivity: electric_conductivity = electric_conductivity
    """
    electric_conductivity child of solid_child.
    """
    dual_electric_conductivity: dual_electric_conductivity = dual_electric_conductivity
    """
    dual_electric_conductivity child of solid_child.
    """
    lithium_diffusivity: lithium_diffusivity = lithium_diffusivity
    """
    lithium_diffusivity child of solid_child.
    """
    magnetic_permeability: magnetic_permeability = magnetic_permeability
    """
    magnetic_permeability child of solid_child.
    """
    struct_youngs_modulus: struct_youngs_modulus = struct_youngs_modulus
    """
    struct_youngs_modulus child of solid_child.
    """
    struct_poisson_ratio: struct_poisson_ratio = struct_poisson_ratio
    """
    struct_poisson_ratio child of solid_child.
    """
    struct_start_temperature: struct_start_temperature = struct_start_temperature
    """
    struct_start_temperature child of solid_child.
    """
    struct_thermal_expansion: struct_thermal_expansion = struct_thermal_expansion
    """
    struct_thermal_expansion child of solid_child.
    """
    struct_damping_alpha: struct_damping_alpha = struct_damping_alpha
    """
    struct_damping_alpha child of solid_child.
    """
    struct_damping_beta: struct_damping_beta = struct_damping_beta
    """
    struct_damping_beta child of solid_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .min_point import min_point
from .max_point import max_point
from .inside import inside
from .create_volume_surface import create_volume_surface
class hexahedron(Group):
    """
    'hexahedron' child.
    """

    fluent_name = "hexahedron"

    child_names = \
        ['min_point', 'max_point', 'inside', 'create_volume_surface']

    min_point: min_point = min_point
    """
    min_point child of hexahedron.
    """
    max_point: max_point = max_point
    """
    max_point child of hexahedron.
    """
    inside: inside = inside
    """
    inside child of hexahedron.
    """
    create_volume_surface: create_volume_surface = create_volume_surface
    """
    create_volume_surface child of hexahedron.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .fluid_1 import fluid
from .solid_1 import solid
class cell_zone_conditions(Group):
    """
    'cell_zone_conditions' child.
    """

    fluent_name = "cell-zone-conditions"

    child_names = \
        ['fluid', 'solid']

    fluid: fluid = fluid
    """
    fluid child of cell_zone_conditions.
    """
    solid: solid = solid
    """
    solid child of cell_zone_conditions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .injections_1 import injections
from .boundaries import boundaries
from .lines_1 import lines
from .planes import planes
from .op_udf import op_udf
from .append_sample import append_sample
from .accumulate_rates import accumulate_rates
class sample(Command):
    """
    'sample' command.
    
    Parameters
    ----------
        injections : typing.List[str]
            'injections' child.
        boundaries : typing.List[str]
            'boundaries' child.
        lines : typing.List[str]
            'lines' child.
        planes : typing.List[str]
            'planes' child.
        op_udf : str
            'op_udf' child.
        append_sample : bool
            'append_sample' child.
        accumulate_rates : bool
            'accumulate_rates' child.
    
    """

    fluent_name = "sample"

    argument_names = \
        ['injections', 'boundaries', 'lines', 'planes', 'op_udf',
         'append_sample', 'accumulate_rates']

    injections: injections = injections
    """
    injections argument of sample.
    """
    boundaries: boundaries = boundaries
    """
    boundaries argument of sample.
    """
    lines: lines = lines
    """
    lines argument of sample.
    """
    planes: planes = planes
    """
    planes argument of sample.
    """
    op_udf: op_udf = op_udf
    """
    op_udf argument of sample.
    """
    append_sample: append_sample = append_sample
    """
    append_sample argument of sample.
    """
    accumulate_rates: accumulate_rates = accumulate_rates
    """
    accumulate_rates argument of sample.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .pseudo_transient import pseudo_transient
from .p_v_coupling import p_v_coupling
from .hybrid_nita import hybrid_nita
from .equation_order import equation_order
from .anti_diffusion import anti_diffusion
class advanced_stability_controls(Group):
    """
    'advanced_stability_controls' child.
    """

    fluent_name = "advanced-stability-controls"

    child_names = \
        ['pseudo_transient', 'p_v_coupling', 'hybrid_nita', 'equation_order',
         'anti_diffusion']

    pseudo_transient: pseudo_transient = pseudo_transient
    """
    pseudo_transient child of advanced_stability_controls.
    """
    p_v_coupling: p_v_coupling = p_v_coupling
    """
    p_v_coupling child of advanced_stability_controls.
    """
    hybrid_nita: hybrid_nita = hybrid_nita
    """
    hybrid_nita child of advanced_stability_controls.
    """
    equation_order: equation_order = equation_order
    """
    equation_order child of advanced_stability_controls.
    """
    anti_diffusion: anti_diffusion = anti_diffusion
    """
    anti_diffusion child of advanced_stability_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .x import x
from .x_2 import x_2
from .y import y
from .y_2 import y_2
from .z import z
from .z_2 import z_2
from .magnitude import magnitude
class angular_velocity(Group):
    """
    'angular_velocity' child.
    """

    fluent_name = "angular-velocity"

    child_names = \
        ['x', 'x_2', 'y', 'y_2', 'z', 'z_2', 'magnitude']

    x: x = x
    """
    x child of angular_velocity.
    """
    x_2: x_2 = x_2
    """
    x_2 child of angular_velocity.
    """
    y: y = y
    """
    y child of angular_velocity.
    """
    y_2: y_2 = y_2
    """
    y_2 child of angular_velocity.
    """
    z: z = z
    """
    z child of angular_velocity.
    """
    z_2: z_2 = z_2
    """
    z_2 child of angular_velocity.
    """
    magnitude: magnitude = magnitude
    """
    magnitude child of angular_velocity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .single_rate import single_rate
from .two_competing_rates import two_competing_rates
from .cpd_model import cpd_model
class devolatilization_model(Group):
    """
    'devolatilization_model' child.
    """

    fluent_name = "devolatilization-model"

    child_names = \
        ['option', 'value', 'single_rate', 'two_competing_rates', 'cpd_model']

    option: option = option
    """
    option child of devolatilization_model.
    """
    value: value = value
    """
    value child of devolatilization_model.
    """
    single_rate: single_rate = single_rate
    """
    single_rate child of devolatilization_model.
    """
    two_competing_rates: two_competing_rates = two_competing_rates
    """
    two_competing_rates child of devolatilization_model.
    """
    cpd_model: cpd_model = cpd_model
    """
    cpd_model child of devolatilization_model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option import option
from .constant_length import constant_length
from .variable_length import variable_length
class vector_length(Group):
    """
    'vector_length' child.
    """

    fluent_name = "vector-length"

    child_names = \
        ['option', 'constant_length', 'variable_length']

    option: option = option
    """
    option child of vector_length.
    """
    constant_length: constant_length = constant_length
    """
    constant_length child of vector_length.
    """
    variable_length: variable_length = variable_length
    """
    variable_length child of vector_length.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .lift_child import lift_child

class lift(NamedObject[lift_child], _CreatableNamedObjectMixin[lift_child]):
    """
    'lift' child.
    """

    fluent_name = "lift"

    child_object_type: lift_child = lift_child
    """
    child_object_type of lift.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .high_order_pressure import high_order_pressure
from .interpolation_method import interpolation_method
from .orphan_cell_treatment import orphan_cell_treatment
from .expert_3 import expert
class overset(Group):
    """
    'overset' child.
    """

    fluent_name = "overset"

    child_names = \
        ['high_order_pressure', 'interpolation_method',
         'orphan_cell_treatment', 'expert']

    high_order_pressure: high_order_pressure = high_order_pressure
    """
    high_order_pressure child of overset.
    """
    interpolation_method: interpolation_method = interpolation_method
    """
    interpolation_method child of overset.
    """
    orphan_cell_treatment: orphan_cell_treatment = orphan_cell_treatment
    """
    orphan_cell_treatment child of overset.
    """
    expert: expert = expert
    """
    expert child of overset.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .combusting_particle_child import combusting_particle_child

class combusting_particle(NamedObject[combusting_particle_child], _CreatableNamedObjectMixin[combusting_particle_child]):
    """
    'combusting_particle' child.
    """

    fluent_name = "combusting-particle"

    child_object_type: combusting_particle_child = combusting_particle_child
    """
    child_object_type of combusting_particle.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .separate_journals import separate_journals
class save_journals(Command):
    """
    Save Journals.
    
    Parameters
    ----------
        separate_journals : bool
            'separate_journals' child.
    
    """

    fluent_name = "save-journals"

    argument_names = \
        ['separate_journals']

    separate_journals: separate_journals = separate_journals
    """
    separate_journals argument of save_journals.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .object_name import object_name
class display(Command):
    """
    Display graphics object.
    
    Parameters
    ----------
        object_name : str
            'object_name' child.
    
    """

    fluent_name = "display"

    argument_names = \
        ['object_name']

    object_name: object_name = object_name
    """
    object_name argument of display.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .convergence_reports import convergence_reports
from .frequency_1 import frequency
from .condition import condition
from .check_for import check_for
class convergence_conditions(Group):
    """
    'convergence_conditions' child.
    """

    fluent_name = "convergence-conditions"

    child_names = \
        ['convergence_reports', 'frequency', 'condition', 'check_for']

    convergence_reports: convergence_reports = convergence_reports
    """
    convergence_reports child of convergence_conditions.
    """
    frequency: frequency = frequency
    """
    frequency child of convergence_conditions.
    """
    condition: condition = condition
    """
    condition child of convergence_conditions.
    """
    check_for: check_for = check_for
    """
    check_for child of convergence_conditions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .equation_for_residual import equation_for_residual
from .threshold import threshold
class residual(Group):
    """
    'residual' child.
    """

    fluent_name = "residual"

    child_names = \
        ['equation_for_residual', 'threshold']

    equation_for_residual: equation_for_residual = equation_for_residual
    """
    equation_for_residual child of residual.
    """
    threshold: threshold = threshold
    """
    threshold child of residual.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .dpm_domain import dpm_domain
from .ordered_accumulation import ordered_accumulation
class hybrid_options(Group):
    """
    'hybrid_options' child.
    """

    fluent_name = "hybrid-options"

    child_names = \
        ['dpm_domain', 'ordered_accumulation']

    dpm_domain: dpm_domain = dpm_domain
    """
    dpm_domain child of hybrid_options.
    """
    ordered_accumulation: ordered_accumulation = ordered_accumulation
    """
    ordered_accumulation child of hybrid_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .pole import pole
from .amplitude import amplitude
class impedance_1_child(Group):
    """
    'child_object_type' of impedance_1.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['pole', 'amplitude']

    pole: pole = pole
    """
    pole child of impedance_1_child.
    """
    amplitude: amplitude = amplitude
    """
    amplitude child of impedance_1_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class kw_add_des(Boolean):
    """
    Enable/disable DES-mode with the current turbulence model.
    """

    fluent_name = "kw-add-des?"




"""Module for maintaining journal."""


class Journal:
    """Manages journal streaming."""

    def __init__(self, scheme_eval):
        self.scheme_eval = scheme_eval

    def start(self, file_path: str):
        """Starts writing a journal to the file_path."""
        self.scheme_eval.exec([f'(api-start-python-journal "{file_path}")'])

    def stop(self):
        """Stops writing the journal."""
        self.scheme_eval.exec([f"(api-stop-python-journal)"])



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .nodes import nodes
from .edges import edges
from .faces import faces
from .partitions import partitions
from .overset_2 import overset
from .gap import gap
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['nodes', 'edges', 'faces', 'partitions', 'overset', 'gap']

    nodes: nodes = nodes
    """
    nodes child of options.
    """
    edges: edges = edges
    """
    edges child of options.
    """
    faces: faces = faces
    """
    faces child of options.
    """
    partitions: partitions = partitions
    """
    partitions child of options.
    """
    overset: overset = overset
    """
    overset child of options.
    """
    gap: gap = gap
    """
    gap child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .uds_diffusivities import uds_diffusivities
from .user_defined_function import user_defined_function
class uds_diffusivity(Group):
    """
    'uds_diffusivity' child.
    """

    fluent_name = "uds-diffusivity"

    child_names = \
        ['option', 'value', 'uds_diffusivities', 'user_defined_function']

    option: option = option
    """
    option child of uds_diffusivity.
    """
    value: value = value
    """
    value child of uds_diffusivity.
    """
    uds_diffusivities: uds_diffusivities = uds_diffusivities
    """
    uds_diffusivities child of uds_diffusivity.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of uds_diffusivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .old_props import old_props
from .previous_values_to_consider import previous_values_to_consider
from .initial_values_to_ignore import initial_values_to_ignore
from .iteration_at_creation_or_edit import iteration_at_creation_or_edit
from .stop_criterion import stop_criterion
from .report_defs_1 import report_defs
from .print_1 import print
from .plot import plot
from .cov import cov
from .active import active
from .x_label import x_label
from .previous_values import previous_values
class convergence_reports_child(Group):
    """
    'child_object_type' of convergence_reports.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'old_props', 'previous_values_to_consider',
         'initial_values_to_ignore', 'iteration_at_creation_or_edit',
         'stop_criterion', 'report_defs', 'print', 'plot', 'cov', 'active',
         'x_label', 'previous_values']

    name: name = name
    """
    name child of convergence_reports_child.
    """
    old_props: old_props = old_props
    """
    old_props child of convergence_reports_child.
    """
    previous_values_to_consider: previous_values_to_consider = previous_values_to_consider
    """
    previous_values_to_consider child of convergence_reports_child.
    """
    initial_values_to_ignore: initial_values_to_ignore = initial_values_to_ignore
    """
    initial_values_to_ignore child of convergence_reports_child.
    """
    iteration_at_creation_or_edit: iteration_at_creation_or_edit = iteration_at_creation_or_edit
    """
    iteration_at_creation_or_edit child of convergence_reports_child.
    """
    stop_criterion: stop_criterion = stop_criterion
    """
    stop_criterion child of convergence_reports_child.
    """
    report_defs: report_defs = report_defs
    """
    report_defs child of convergence_reports_child.
    """
    print: print = print
    """
    print child of convergence_reports_child.
    """
    plot: plot = plot
    """
    plot child of convergence_reports_child.
    """
    cov: cov = cov
    """
    cov child of convergence_reports_child.
    """
    active: active = active
    """
    active child of convergence_reports_child.
    """
    x_label: x_label = x_label
    """
    x_label child of convergence_reports_child.
    """
    previous_values: previous_values = previous_values
    """
    previous_values child of convergence_reports_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .single_val_expression_child import single_val_expression_child

class single_val_expression(NamedObject[single_val_expression_child], _CreatableNamedObjectMixin[single_val_expression_child]):
    """
    'single_val_expression' child.
    """

    fluent_name = "single-val-expression"

    child_object_type: single_val_expression_child = single_val_expression_child
    """
    child_object_type of single_val_expression.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .hexahedron import hexahedron
from .sphere import sphere
from .cylinder import cylinder
from .boundary import boundary
from .limiters import limiters
from .field_value import field_value
from .residual import residual
from .volume_1 import volume
from .yplus_star import yplus_star
from .yplus_ystar import yplus_ystar
class type(Group):
    """
    'type' child.
    """

    fluent_name = "type"

    child_names = \
        ['option', 'hexahedron', 'sphere', 'cylinder', 'boundary', 'limiters',
         'field_value', 'residual', 'volume', 'yplus_star', 'yplus_ystar']

    option: option = option
    """
    option child of type.
    """
    hexahedron: hexahedron = hexahedron
    """
    hexahedron child of type.
    """
    sphere: sphere = sphere
    """
    sphere child of type.
    """
    cylinder: cylinder = cylinder
    """
    cylinder child of type.
    """
    boundary: boundary = boundary
    """
    boundary child of type.
    """
    limiters: limiters = limiters
    """
    limiters child of type.
    """
    field_value: field_value = field_value
    """
    field_value child of type.
    """
    residual: residual = residual
    """
    residual child of type.
    """
    volume: volume = volume
    """
    volume child of type.
    """
    yplus_star: yplus_star = yplus_star
    """
    yplus_star child of type.
    """
    yplus_ystar: yplus_ystar = yplus_ystar
    """
    yplus_ystar child of type.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .plot_window import plot_window
from .old_props import old_props
from .frequency import frequency
from .flow_frequency import flow_frequency
from .frequency_of import frequency_of
from .report_defs import report_defs
from .print_1 import print
from .title import title
from .x_label import x_label
from .y_label import y_label
from .active import active
from .plot_instantaneous_values import plot_instantaneous_values
class report_plots_child(Group):
    """
    'child_object_type' of report_plots.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'plot_window', 'old_props', 'frequency', 'flow_frequency',
         'frequency_of', 'report_defs', 'print', 'title', 'x_label',
         'y_label', 'active', 'plot_instantaneous_values']

    name: name = name
    """
    name child of report_plots_child.
    """
    plot_window: plot_window = plot_window
    """
    plot_window child of report_plots_child.
    """
    old_props: old_props = old_props
    """
    old_props child of report_plots_child.
    """
    frequency: frequency = frequency
    """
    frequency child of report_plots_child.
    """
    flow_frequency: flow_frequency = flow_frequency
    """
    flow_frequency child of report_plots_child.
    """
    frequency_of: frequency_of = frequency_of
    """
    frequency_of child of report_plots_child.
    """
    report_defs: report_defs = report_defs
    """
    report_defs child of report_plots_child.
    """
    print: print = print
    """
    print child of report_plots_child.
    """
    title: title = title
    """
    title child of report_plots_child.
    """
    x_label: x_label = x_label
    """
    x_label child of report_plots_child.
    """
    y_label: y_label = y_label
    """
    y_label child of report_plots_child.
    """
    active: active = active
    """
    active child of report_plots_child.
    """
    plot_instantaneous_values: plot_instantaneous_values = plot_instantaneous_values
    """
    plot_instantaneous_values child of report_plots_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .proc_statistics import proc_statistics
from .sys_statistics import sys_statistics
from .gpgpu_statistics import gpgpu_statistics
from .time_statistics import time_statistics
class system(Group):
    """
    'system' child.
    """

    fluent_name = "system"

    command_names = \
        ['proc_statistics', 'sys_statistics', 'gpgpu_statistics',
         'time_statistics']

    proc_statistics: proc_statistics = proc_statistics
    """
    proc_statistics command of system.
    """
    sys_statistics: sys_statistics = sys_statistics
    """
    sys_statistics command of system.
    """
    gpgpu_statistics: gpgpu_statistics = gpgpu_statistics
    """
    gpgpu_statistics command of system.
    """
    time_statistics: time_statistics = time_statistics
    """
    time_statistics command of system.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .light_number import light_number
from .light_on import light_on
from .rgb_vector import rgb_vector
from .use_view_factor import use_view_factor
from .change_light_direction import change_light_direction
from .direction_vector_1 import direction_vector
class set_light(Command):
    """
    'set_light' command.
    
    Parameters
    ----------
        light_number : int
            'light_number' child.
        light_on : bool
            'light_on' child.
        rgb_vector : typing.Tuple[real, real, real]
            'rgb_vector' child.
        use_view_factor : bool
            'use_view_factor' child.
        change_light_direction : bool
            'change_light_direction' child.
        direction_vector : typing.Tuple[real, real, real]
            'direction_vector' child.
    
    """

    fluent_name = "set-light"

    argument_names = \
        ['light_number', 'light_on', 'rgb_vector', 'use_view_factor',
         'change_light_direction', 'direction_vector']

    light_number: light_number = light_number
    """
    light_number argument of set_light.
    """
    light_on: light_on = light_on
    """
    light_on argument of set_light.
    """
    rgb_vector: rgb_vector = rgb_vector
    """
    rgb_vector argument of set_light.
    """
    use_view_factor: use_view_factor = use_view_factor
    """
    use_view_factor argument of set_light.
    """
    change_light_direction: change_light_direction = change_light_direction
    """
    change_light_direction argument of set_light.
    """
    direction_vector: direction_vector = direction_vector
    """
    direction_vector argument of set_light.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .open_channel import open_channel
from .outlet_number import outlet_number
from .pressure_spec_method import pressure_spec_method
from .press_spec import press_spec
from .frame_of_reference import frame_of_reference
from .phase_spec import phase_spec
from .ht_local import ht_local
from .gauge_pressure import gauge_pressure
from .p_profile_multiplier import p_profile_multiplier
from .ht_bottom import ht_bottom
from .den_spec import den_spec
from .t0 import t0
from .direction_spec import direction_spec
from .coordinate_system import coordinate_system
from .flow_direction import flow_direction
from .axis_direction_2 import axis_direction
from .axis_origin_2 import axis_origin
from .ke_spec import ke_spec
from .nut import nut
from .kl import kl
from .intermit import intermit
from .k import k
from .e import e
from .o import o
from .v2 import v2
from .turb_intensity import turb_intensity
from .turb_length_scale import turb_length_scale
from .turb_hydraulic_diam import turb_hydraulic_diam
from .turb_viscosity_ratio import turb_viscosity_ratio
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile
from .rst_spec import rst_spec
from .uu import uu
from .vv import vv
from .ww import ww
from .uv import uv
from .vw import vw
from .uw import uw
from .ksgs_spec import ksgs_spec
from .ksgs import ksgs
from .sgs_turb_intensity import sgs_turb_intensity
from .radiation_bc import radiation_bc
from .radial_direction import radial_direction
from .coll_dtheta import coll_dtheta
from .coll_dphi import coll_dphi
from .band_q_irrad import band_q_irrad
from .band_q_irrad_diffuse import band_q_irrad_diffuse
from .parallel_collimated_beam import parallel_collimated_beam
from .solar_direction import solar_direction
from .solar_irradiation import solar_irradiation
from .t_b_b_spec import t_b_b_spec
from .t_b_b import t_b_b
from .in_emiss import in_emiss
from .fmean import fmean
from .fmean2 import fmean2
from .fvar import fvar
from .fvar2 import fvar2
from .granular_temperature import granular_temperature
from .iac import iac
from .lsfun import lsfun
from .vof_spec import vof_spec
from .volume_fraction import volume_fraction
from .species_in_mole_fractions import species_in_mole_fractions
from .mf import mf
from .elec_potential_type import elec_potential_type
from .potential_value import potential_value
from .dual_potential_type import dual_potential_type
from .dual_potential_value import dual_potential_value
from .x_displacement_type import x_displacement_type
from .x_displacement_value import x_displacement_value
from .y_displacement_type import y_displacement_type
from .y_displacement_value import y_displacement_value
from .z_displacement_type import z_displacement_type
from .z_displacement_value import z_displacement_value
from .prob_mode_1 import prob_mode_1
from .prob_mode_2 import prob_mode_2
from .prob_mode_3 import prob_mode_3
from .premixc import premixc
from .premixc_var import premixc_var
from .ecfm_sigma import ecfm_sigma
from .inert import inert
from .pollut_no import pollut_no
from .pollut_hcn import pollut_hcn
from .pollut_nh3 import pollut_nh3
from .pollut_n2o import pollut_n2o
from .pollut_urea import pollut_urea
from .pollut_hnco import pollut_hnco
from .pollut_nco import pollut_nco
from .pollut_so2 import pollut_so2
from .pollut_h2s import pollut_h2s
from .pollut_so3 import pollut_so3
from .pollut_sh import pollut_sh
from .pollut_so import pollut_so
from .pollut_soot import pollut_soot
from .pollut_nuclei import pollut_nuclei
from .pollut_ctar import pollut_ctar
from .pollut_hg import pollut_hg
from .pollut_hgcl2 import pollut_hgcl2
from .pollut_hcl import pollut_hcl
from .pollut_hgo import pollut_hgo
from .pollut_cl import pollut_cl
from .pollut_cl2 import pollut_cl2
from .pollut_hgcl import pollut_hgcl
from .pollut_hocl import pollut_hocl
from .tss_scalar import tss_scalar
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype
from .uds_bc import uds_bc
from .uds import uds
from .pb_disc_bc import pb_disc_bc
from .pb_disc import pb_disc
from .pb_qmom_bc import pb_qmom_bc
from .pb_qmom import pb_qmom
from .pb_smm_bc import pb_smm_bc
from .pb_smm import pb_smm
from .pb_dqmom_bc import pb_dqmom_bc
from .pb_dqmom import pb_dqmom
from .dpm_bc_type import dpm_bc_type
from .dpm_bc_collision_partner import dpm_bc_collision_partner
from .reinj_inj import reinj_inj
from .dpm_bc_udf import dpm_bc_udf
from .mixing_plane_thread import mixing_plane_thread
from .ac_options import ac_options
from .p_backflow_spec import p_backflow_spec
from .p_backflow_spec_gen import p_backflow_spec_gen
from .impedance_0 import impedance_0
from .impedance_1 import impedance_1
from .impedance_2 import impedance_2
from .ac_wave import ac_wave
from .prevent_reverse_flow import prevent_reverse_flow
from .radial import radial
from .avg_press_spec import avg_press_spec
from .press_averaging_method import press_averaging_method
from .targeted_mf_boundary import targeted_mf_boundary
from .targeted_mf import targeted_mf
from .targeted_mf_pmax import targeted_mf_pmax
from .targeted_mf_pmin import targeted_mf_pmin
from .gen_nrbc_spec import gen_nrbc_spec
from .wsf import wsf
from .wsb import wsb
from .wsn import wsn
from .solar_fluxes import solar_fluxes
from .solar_shining_factor import solar_shining_factor
from .radiating_s2s_surface import radiating_s2s_surface
from .b_1 import b
from .strength import strength
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'open_channel',
         'outlet_number', 'pressure_spec_method', 'press_spec',
         'frame_of_reference', 'phase_spec', 'ht_local', 'gauge_pressure',
         'p_profile_multiplier', 'ht_bottom', 'den_spec', 't0',
         'direction_spec', 'coordinate_system', 'flow_direction',
         'axis_direction', 'axis_origin', 'ke_spec', 'nut', 'kl', 'intermit',
         'k', 'e', 'o', 'v2', 'turb_intensity', 'turb_length_scale',
         'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'radiation_bc', 'radial_direction', 'coll_dtheta', 'coll_dphi',
         'band_q_irrad', 'band_q_irrad_diffuse', 'parallel_collimated_beam',
         'solar_direction', 'solar_irradiation', 't_b_b_spec', 't_b_b',
         'in_emiss', 'fmean', 'fmean2', 'fvar', 'fvar2',
         'granular_temperature', 'iac', 'lsfun', 'vof_spec',
         'volume_fraction', 'species_in_mole_fractions', 'mf',
         'elec_potential_type', 'potential_value', 'dual_potential_type',
         'dual_potential_value', 'x_displacement_type',
         'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'prob_mode_1', 'prob_mode_2', 'prob_mode_3',
         'premixc', 'premixc_var', 'ecfm_sigma', 'inert', 'pollut_no',
         'pollut_hcn', 'pollut_nh3', 'pollut_n2o', 'pollut_urea',
         'pollut_hnco', 'pollut_nco', 'pollut_so2', 'pollut_h2s',
         'pollut_so3', 'pollut_sh', 'pollut_so', 'pollut_soot',
         'pollut_nuclei', 'pollut_ctar', 'pollut_hg', 'pollut_hgcl2',
         'pollut_hcl', 'pollut_hgo', 'pollut_cl', 'pollut_cl2', 'pollut_hgcl',
         'pollut_hocl', 'tss_scalar', 'fensapice_flow_bc_subtype', 'uds_bc',
         'uds', 'pb_disc_bc', 'pb_disc', 'pb_qmom_bc', 'pb_qmom', 'pb_smm_bc',
         'pb_smm', 'pb_dqmom_bc', 'pb_dqmom', 'dpm_bc_type',
         'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'mixing_plane_thread', 'ac_options', 'p_backflow_spec',
         'p_backflow_spec_gen', 'impedance_0', 'impedance_1', 'impedance_2',
         'ac_wave', 'prevent_reverse_flow', 'radial', 'avg_press_spec',
         'press_averaging_method', 'targeted_mf_boundary', 'targeted_mf',
         'targeted_mf_pmax', 'targeted_mf_pmin', 'gen_nrbc_spec', 'wsf',
         'wsb', 'wsn', 'solar_fluxes', 'solar_shining_factor',
         'radiating_s2s_surface', 'b', 'strength']

    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of phase_child.
    """
    open_channel: open_channel = open_channel
    """
    open_channel child of phase_child.
    """
    outlet_number: outlet_number = outlet_number
    """
    outlet_number child of phase_child.
    """
    pressure_spec_method: pressure_spec_method = pressure_spec_method
    """
    pressure_spec_method child of phase_child.
    """
    press_spec: press_spec = press_spec
    """
    press_spec child of phase_child.
    """
    frame_of_reference: frame_of_reference = frame_of_reference
    """
    frame_of_reference child of phase_child.
    """
    phase_spec: phase_spec = phase_spec
    """
    phase_spec child of phase_child.
    """
    ht_local: ht_local = ht_local
    """
    ht_local child of phase_child.
    """
    gauge_pressure: gauge_pressure = gauge_pressure
    """
    gauge_pressure child of phase_child.
    """
    p_profile_multiplier: p_profile_multiplier = p_profile_multiplier
    """
    p_profile_multiplier child of phase_child.
    """
    ht_bottom: ht_bottom = ht_bottom
    """
    ht_bottom child of phase_child.
    """
    den_spec: den_spec = den_spec
    """
    den_spec child of phase_child.
    """
    t0: t0 = t0
    """
    t0 child of phase_child.
    """
    direction_spec: direction_spec = direction_spec
    """
    direction_spec child of phase_child.
    """
    coordinate_system: coordinate_system = coordinate_system
    """
    coordinate_system child of phase_child.
    """
    flow_direction: flow_direction = flow_direction
    """
    flow_direction child of phase_child.
    """
    axis_direction: axis_direction = axis_direction
    """
    axis_direction child of phase_child.
    """
    axis_origin: axis_origin = axis_origin
    """
    axis_origin child of phase_child.
    """
    ke_spec: ke_spec = ke_spec
    """
    ke_spec child of phase_child.
    """
    nut: nut = nut
    """
    nut child of phase_child.
    """
    kl: kl = kl
    """
    kl child of phase_child.
    """
    intermit: intermit = intermit
    """
    intermit child of phase_child.
    """
    k: k = k
    """
    k child of phase_child.
    """
    e: e = e
    """
    e child of phase_child.
    """
    o: o = o
    """
    o child of phase_child.
    """
    v2: v2 = v2
    """
    v2 child of phase_child.
    """
    turb_intensity: turb_intensity = turb_intensity
    """
    turb_intensity child of phase_child.
    """
    turb_length_scale: turb_length_scale = turb_length_scale
    """
    turb_length_scale child of phase_child.
    """
    turb_hydraulic_diam: turb_hydraulic_diam = turb_hydraulic_diam
    """
    turb_hydraulic_diam child of phase_child.
    """
    turb_viscosity_ratio: turb_viscosity_ratio = turb_viscosity_ratio
    """
    turb_viscosity_ratio child of phase_child.
    """
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile = turb_viscosity_ratio_profile
    """
    turb_viscosity_ratio_profile child of phase_child.
    """
    rst_spec: rst_spec = rst_spec
    """
    rst_spec child of phase_child.
    """
    uu: uu = uu
    """
    uu child of phase_child.
    """
    vv: vv = vv
    """
    vv child of phase_child.
    """
    ww: ww = ww
    """
    ww child of phase_child.
    """
    uv: uv = uv
    """
    uv child of phase_child.
    """
    vw: vw = vw
    """
    vw child of phase_child.
    """
    uw: uw = uw
    """
    uw child of phase_child.
    """
    ksgs_spec: ksgs_spec = ksgs_spec
    """
    ksgs_spec child of phase_child.
    """
    ksgs: ksgs = ksgs
    """
    ksgs child of phase_child.
    """
    sgs_turb_intensity: sgs_turb_intensity = sgs_turb_intensity
    """
    sgs_turb_intensity child of phase_child.
    """
    radiation_bc: radiation_bc = radiation_bc
    """
    radiation_bc child of phase_child.
    """
    radial_direction: radial_direction = radial_direction
    """
    radial_direction child of phase_child.
    """
    coll_dtheta: coll_dtheta = coll_dtheta
    """
    coll_dtheta child of phase_child.
    """
    coll_dphi: coll_dphi = coll_dphi
    """
    coll_dphi child of phase_child.
    """
    band_q_irrad: band_q_irrad = band_q_irrad
    """
    band_q_irrad child of phase_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse = band_q_irrad_diffuse
    """
    band_q_irrad_diffuse child of phase_child.
    """
    parallel_collimated_beam: parallel_collimated_beam = parallel_collimated_beam
    """
    parallel_collimated_beam child of phase_child.
    """
    solar_direction: solar_direction = solar_direction
    """
    solar_direction child of phase_child.
    """
    solar_irradiation: solar_irradiation = solar_irradiation
    """
    solar_irradiation child of phase_child.
    """
    t_b_b_spec: t_b_b_spec = t_b_b_spec
    """
    t_b_b_spec child of phase_child.
    """
    t_b_b: t_b_b = t_b_b
    """
    t_b_b child of phase_child.
    """
    in_emiss: in_emiss = in_emiss
    """
    in_emiss child of phase_child.
    """
    fmean: fmean = fmean
    """
    fmean child of phase_child.
    """
    fmean2: fmean2 = fmean2
    """
    fmean2 child of phase_child.
    """
    fvar: fvar = fvar
    """
    fvar child of phase_child.
    """
    fvar2: fvar2 = fvar2
    """
    fvar2 child of phase_child.
    """
    granular_temperature: granular_temperature = granular_temperature
    """
    granular_temperature child of phase_child.
    """
    iac: iac = iac
    """
    iac child of phase_child.
    """
    lsfun: lsfun = lsfun
    """
    lsfun child of phase_child.
    """
    vof_spec: vof_spec = vof_spec
    """
    vof_spec child of phase_child.
    """
    volume_fraction: volume_fraction = volume_fraction
    """
    volume_fraction child of phase_child.
    """
    species_in_mole_fractions: species_in_mole_fractions = species_in_mole_fractions
    """
    species_in_mole_fractions child of phase_child.
    """
    mf: mf = mf
    """
    mf child of phase_child.
    """
    elec_potential_type: elec_potential_type = elec_potential_type
    """
    elec_potential_type child of phase_child.
    """
    potential_value: potential_value = potential_value
    """
    potential_value child of phase_child.
    """
    dual_potential_type: dual_potential_type = dual_potential_type
    """
    dual_potential_type child of phase_child.
    """
    dual_potential_value: dual_potential_value = dual_potential_value
    """
    dual_potential_value child of phase_child.
    """
    x_displacement_type: x_displacement_type = x_displacement_type
    """
    x_displacement_type child of phase_child.
    """
    x_displacement_value: x_displacement_value = x_displacement_value
    """
    x_displacement_value child of phase_child.
    """
    y_displacement_type: y_displacement_type = y_displacement_type
    """
    y_displacement_type child of phase_child.
    """
    y_displacement_value: y_displacement_value = y_displacement_value
    """
    y_displacement_value child of phase_child.
    """
    z_displacement_type: z_displacement_type = z_displacement_type
    """
    z_displacement_type child of phase_child.
    """
    z_displacement_value: z_displacement_value = z_displacement_value
    """
    z_displacement_value child of phase_child.
    """
    prob_mode_1: prob_mode_1 = prob_mode_1
    """
    prob_mode_1 child of phase_child.
    """
    prob_mode_2: prob_mode_2 = prob_mode_2
    """
    prob_mode_2 child of phase_child.
    """
    prob_mode_3: prob_mode_3 = prob_mode_3
    """
    prob_mode_3 child of phase_child.
    """
    premixc: premixc = premixc
    """
    premixc child of phase_child.
    """
    premixc_var: premixc_var = premixc_var
    """
    premixc_var child of phase_child.
    """
    ecfm_sigma: ecfm_sigma = ecfm_sigma
    """
    ecfm_sigma child of phase_child.
    """
    inert: inert = inert
    """
    inert child of phase_child.
    """
    pollut_no: pollut_no = pollut_no
    """
    pollut_no child of phase_child.
    """
    pollut_hcn: pollut_hcn = pollut_hcn
    """
    pollut_hcn child of phase_child.
    """
    pollut_nh3: pollut_nh3 = pollut_nh3
    """
    pollut_nh3 child of phase_child.
    """
    pollut_n2o: pollut_n2o = pollut_n2o
    """
    pollut_n2o child of phase_child.
    """
    pollut_urea: pollut_urea = pollut_urea
    """
    pollut_urea child of phase_child.
    """
    pollut_hnco: pollut_hnco = pollut_hnco
    """
    pollut_hnco child of phase_child.
    """
    pollut_nco: pollut_nco = pollut_nco
    """
    pollut_nco child of phase_child.
    """
    pollut_so2: pollut_so2 = pollut_so2
    """
    pollut_so2 child of phase_child.
    """
    pollut_h2s: pollut_h2s = pollut_h2s
    """
    pollut_h2s child of phase_child.
    """
    pollut_so3: pollut_so3 = pollut_so3
    """
    pollut_so3 child of phase_child.
    """
    pollut_sh: pollut_sh = pollut_sh
    """
    pollut_sh child of phase_child.
    """
    pollut_so: pollut_so = pollut_so
    """
    pollut_so child of phase_child.
    """
    pollut_soot: pollut_soot = pollut_soot
    """
    pollut_soot child of phase_child.
    """
    pollut_nuclei: pollut_nuclei = pollut_nuclei
    """
    pollut_nuclei child of phase_child.
    """
    pollut_ctar: pollut_ctar = pollut_ctar
    """
    pollut_ctar child of phase_child.
    """
    pollut_hg: pollut_hg = pollut_hg
    """
    pollut_hg child of phase_child.
    """
    pollut_hgcl2: pollut_hgcl2 = pollut_hgcl2
    """
    pollut_hgcl2 child of phase_child.
    """
    pollut_hcl: pollut_hcl = pollut_hcl
    """
    pollut_hcl child of phase_child.
    """
    pollut_hgo: pollut_hgo = pollut_hgo
    """
    pollut_hgo child of phase_child.
    """
    pollut_cl: pollut_cl = pollut_cl
    """
    pollut_cl child of phase_child.
    """
    pollut_cl2: pollut_cl2 = pollut_cl2
    """
    pollut_cl2 child of phase_child.
    """
    pollut_hgcl: pollut_hgcl = pollut_hgcl
    """
    pollut_hgcl child of phase_child.
    """
    pollut_hocl: pollut_hocl = pollut_hocl
    """
    pollut_hocl child of phase_child.
    """
    tss_scalar: tss_scalar = tss_scalar
    """
    tss_scalar child of phase_child.
    """
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype = fensapice_flow_bc_subtype
    """
    fensapice_flow_bc_subtype child of phase_child.
    """
    uds_bc: uds_bc = uds_bc
    """
    uds_bc child of phase_child.
    """
    uds: uds = uds
    """
    uds child of phase_child.
    """
    pb_disc_bc: pb_disc_bc = pb_disc_bc
    """
    pb_disc_bc child of phase_child.
    """
    pb_disc: pb_disc = pb_disc
    """
    pb_disc child of phase_child.
    """
    pb_qmom_bc: pb_qmom_bc = pb_qmom_bc
    """
    pb_qmom_bc child of phase_child.
    """
    pb_qmom: pb_qmom = pb_qmom
    """
    pb_qmom child of phase_child.
    """
    pb_smm_bc: pb_smm_bc = pb_smm_bc
    """
    pb_smm_bc child of phase_child.
    """
    pb_smm: pb_smm = pb_smm
    """
    pb_smm child of phase_child.
    """
    pb_dqmom_bc: pb_dqmom_bc = pb_dqmom_bc
    """
    pb_dqmom_bc child of phase_child.
    """
    pb_dqmom: pb_dqmom = pb_dqmom
    """
    pb_dqmom child of phase_child.
    """
    dpm_bc_type: dpm_bc_type = dpm_bc_type
    """
    dpm_bc_type child of phase_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner = dpm_bc_collision_partner
    """
    dpm_bc_collision_partner child of phase_child.
    """
    reinj_inj: reinj_inj = reinj_inj
    """
    reinj_inj child of phase_child.
    """
    dpm_bc_udf: dpm_bc_udf = dpm_bc_udf
    """
    dpm_bc_udf child of phase_child.
    """
    mixing_plane_thread: mixing_plane_thread = mixing_plane_thread
    """
    mixing_plane_thread child of phase_child.
    """
    ac_options: ac_options = ac_options
    """
    ac_options child of phase_child.
    """
    p_backflow_spec: p_backflow_spec = p_backflow_spec
    """
    p_backflow_spec child of phase_child.
    """
    p_backflow_spec_gen: p_backflow_spec_gen = p_backflow_spec_gen
    """
    p_backflow_spec_gen child of phase_child.
    """
    impedance_0: impedance_0 = impedance_0
    """
    impedance_0 child of phase_child.
    """
    impedance_1: impedance_1 = impedance_1
    """
    impedance_1 child of phase_child.
    """
    impedance_2: impedance_2 = impedance_2
    """
    impedance_2 child of phase_child.
    """
    ac_wave: ac_wave = ac_wave
    """
    ac_wave child of phase_child.
    """
    prevent_reverse_flow: prevent_reverse_flow = prevent_reverse_flow
    """
    prevent_reverse_flow child of phase_child.
    """
    radial: radial = radial
    """
    radial child of phase_child.
    """
    avg_press_spec: avg_press_spec = avg_press_spec
    """
    avg_press_spec child of phase_child.
    """
    press_averaging_method: press_averaging_method = press_averaging_method
    """
    press_averaging_method child of phase_child.
    """
    targeted_mf_boundary: targeted_mf_boundary = targeted_mf_boundary
    """
    targeted_mf_boundary child of phase_child.
    """
    targeted_mf: targeted_mf = targeted_mf
    """
    targeted_mf child of phase_child.
    """
    targeted_mf_pmax: targeted_mf_pmax = targeted_mf_pmax
    """
    targeted_mf_pmax child of phase_child.
    """
    targeted_mf_pmin: targeted_mf_pmin = targeted_mf_pmin
    """
    targeted_mf_pmin child of phase_child.
    """
    gen_nrbc_spec: gen_nrbc_spec = gen_nrbc_spec
    """
    gen_nrbc_spec child of phase_child.
    """
    wsf: wsf = wsf
    """
    wsf child of phase_child.
    """
    wsb: wsb = wsb
    """
    wsb child of phase_child.
    """
    wsn: wsn = wsn
    """
    wsn child of phase_child.
    """
    solar_fluxes: solar_fluxes = solar_fluxes
    """
    solar_fluxes child of phase_child.
    """
    solar_shining_factor: solar_shining_factor = solar_shining_factor
    """
    solar_shining_factor child of phase_child.
    """
    radiating_s2s_surface: radiating_s2s_surface = radiating_s2s_surface
    """
    radiating_s2s_surface child of phase_child.
    """
    b: b = b
    """
    b child of phase_child.
    """
    strength: strength = strength
    """
    strength child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .time_step_method import time_step_method
from .pseudo_time_step_size import pseudo_time_step_size
from .length_scale_methods import length_scale_methods
from .time_step_size_scale_factor_1 import time_step_size_scale_factor
from .length_scale_1 import length_scale
from .auto_time_size_calc_solid_zone import auto_time_size_calc_solid_zone
from .time_solid_scale_factor import time_solid_scale_factor
from .time_step_size_for_solid_zone import time_step_size_for_solid_zone
class time_step_method(Group):
    """
    'time_step_method' child.
    """

    fluent_name = "time-step-method"

    child_names = \
        ['time_step_method', 'pseudo_time_step_size', 'length_scale_methods',
         'time_step_size_scale_factor', 'length_scale',
         'auto_time_size_calc_solid_zone', 'time_solid_scale_factor',
         'time_step_size_for_solid_zone']

    time_step_method: time_step_method = time_step_method
    """
    time_step_method child of time_step_method.
    """
    pseudo_time_step_size: pseudo_time_step_size = pseudo_time_step_size
    """
    pseudo_time_step_size child of time_step_method.
    """
    length_scale_methods: length_scale_methods = length_scale_methods
    """
    length_scale_methods child of time_step_method.
    """
    time_step_size_scale_factor: time_step_size_scale_factor = time_step_size_scale_factor
    """
    time_step_size_scale_factor child of time_step_method.
    """
    length_scale: length_scale = length_scale
    """
    length_scale child of time_step_method.
    """
    auto_time_size_calc_solid_zone: auto_time_size_calc_solid_zone = auto_time_size_calc_solid_zone
    """
    auto_time_size_calc_solid_zone child of time_step_method.
    """
    time_solid_scale_factor: time_solid_scale_factor = time_solid_scale_factor
    """
    time_solid_scale_factor child of time_step_method.
    """
    time_step_size_for_solid_zone: time_step_size_for_solid_zone = time_step_size_for_solid_zone
    """
    time_step_size_for_solid_zone child of time_step_method.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class explicit_volume_fraction_under_relaxation(Real):
    """
    Set explicit volume fraction under-relaxation.
    """

    fluent_name = "explicit-volume-fraction-under-relaxation"

